﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Framework
{
    public class AlarmDALImpl : IAlarmDAL
    {
              
        Framework.Linq.LinqToSqlDataContext dataContext = new Framework.Linq.LinqToSqlDataContext();
        IConfigurationDAL conf = new ConfigurationDALImpl();

        public bool NewAlarm(int _serverServiceId, int _userId)
        {

            try
            {
                var searchAlarms = (from s in dataContext.Alarm
                                    select (s.alarm_id)).Max();


                Linq.Alarm _alarm = new Linq.Alarm();

                _alarm.alarm_id = searchAlarms + 1;
                _alarm.instant = DateTime.Now;
                _alarm.serverService_id = _serverServiceId;
                _alarm.user_id = _userId;
                //Initial state - Create and unread
                _alarm.status = 0; 

                dataContext.Alarm.InsertOnSubmit(_alarm);
                dataContext.SubmitChanges();

                conf.writeLog("NewAlarm - " + _serverServiceId + " - " + _userId);                     
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public Alarm GetAlarmById(int _alarmId)
        {

            try
            {
                Alarm _alarm = new Alarm();

                var searchAlarms = from s in dataContext.Alarm
                                   where s.alarm_id == _alarmId
                                   select s;

                if (searchAlarms.Count() > 0)
                {
                    _alarm.AlarmId = searchAlarms.First().alarm_id;
                    _alarm.Instant = searchAlarms.First().instant;
                    _alarm.ServerServiceId = searchAlarms.First().serverService_id;
                    _alarm.UserId = searchAlarms.First().user_id;
                    _alarm.Status = (int)searchAlarms.First().status;
                }

                conf.writeLog("GetAlrmId - " + _alarmId);
                return _alarm;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public bool AlarmLastHourForUser(int _serverServiceId, int _userId)
        {
            try
            {

                var searchAlarm = (from alarms in dataContext.Alarm
                                   where alarms.user_id == _userId
                                      && alarms.serverService_id == _serverServiceId
                                     && ((DateTime.Now - alarms.instant).TotalMinutes < 60)
                                   select alarms).Count();

                if (searchAlarm > 0)
                {
                    //Verify if last 5 minutes the service was up
                    var searchServ = (from srv in dataContext.History
                                       where srv.serverService_id == _serverServiceId
                                          && srv.status == 1
                                         && ((DateTime.Now - srv.instant).TotalMinutes < 5)
                                       select srv).Count();
                    
                    //Veryfy if in the last 5 minutes wasn't any alarm
                    var searchServ2 = (from srv in dataContext.History
                                      where srv.serverService_id == _serverServiceId
                                         && srv.status == 0
                                        && ((DateTime.Now - srv.instant).TotalMinutes < 5)
                                        && ((DateTime.Now - srv.instant).TotalSeconds > 25)
                                      select srv).Count();

                    //if in the last 5 minutes the service was up
                    //and not have any alarm
                    if (searchServ > 0 && searchServ2 == 0)
                        return false;
                    else
                        return true;
                }
                else
                {
                    return false;
                }
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public List<Alarm> GetAlarmsForUser(int _userId)
        {
            List<Alarm> alarms = new List<Alarm>();

            try
            {
                var searchAlarm = from _alarms in dataContext.Alarm
                                  where _alarms.user_id.Equals(_userId)
                                  select _alarms;

                foreach (var _alarm in searchAlarm)
                {
                    if (_alarm.status.Equals(0))
                    
                        alarms.Add( new Alarm(_alarm.alarm_id, _alarm.instant, _alarm.serverService_id, _alarm.user_id, 0));
                    
                    else
                    
                        alarms.Add( new Alarm(_alarm.alarm_id, _alarm.instant, _alarm.serverService_id, _alarm.user_id, 1));
                }

                conf.writeLog("GetAlarmsForUser - " + _userId);
                return alarms;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public List<Alarm> GetAlarmsUnreadForUser(int _userId)
        {
            List<Alarm> alarms = new List<Alarm>();

            try
            {
                var searchAlarm =   from _alarms in dataContext.Alarm
                                   where _alarms.user_id.Equals(_userId)
                                      && _alarms.status.Equals(0)
                                  select _alarms;

                foreach(var _alarm in searchAlarm)
                {
                        Alarm alarm = new Alarm(_alarm.alarm_id, _alarm.instant, _alarm.serverService_id, _alarm.user_id, 0);
                        alarms.Add(alarm);
                }
                conf.writeLog("GetAlarmsUnreadForUser - " + _userId );
                return alarms;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public bool ReadAlarm(int _alarmId)
        {
            try
            {
                var search = from _alarms in dataContext.Alarm
                             where (_alarms.alarm_id == _alarmId)
                             select _alarms;

                if (search.Count() > 0)
                {
                    search.First().status = 1;
                }

                dataContext.SubmitChanges();

                conf.writeLog("ReadAlarm - " + _alarmId);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

    }
}
