﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Framework
{
    public class RealTimeDALImpl : IRealTimeDAL
    {
        Linq.LinqToSqlDataContext dataContext = new Linq.LinqToSqlDataContext();
        IConfigurationDAL conf = new ConfigurationDALImpl();

        public bool DeleteRealTime()
        {

            try
            {
                var deleteRealTime = from realTimes in dataContext.RealTime
                                     select realTimes;

                foreach (var realTime in deleteRealTime)
                {
                    dataContext.RealTime.DeleteOnSubmit(realTime);
                }

                dataContext.SubmitChanges();

                return true;
            }
            catch
            {
                return false;
            }

        }

        public bool InsertRealTime(int _serverServiceId, int _status)
        {

            try
            {

                Linq.RealTime rt = new Linq.RealTime();
                
                rt.serverService_id = _serverServiceId;
                rt.status = _status;
                dataContext.RealTime.InsertOnSubmit(rt);
                dataContext.SubmitChanges();

                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool UpdatetRealTime(int _serverServiceId, int _status)
        {
            try
            {
                var searchRealTime = from s in dataContext.RealTime
                                       where s.serverService_id == _serverServiceId
                                       select s;

                foreach (var rt in searchRealTime)
                {
                    rt.status = _status;
                }

                dataContext.SubmitChanges();

                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool InsertHistory(DateTime _instant, int _serverServiceId, int _status)
        {

            try
            {

                Linq.History ht = new Linq.History();
                ht.instant = _instant;
                ht.serverService_id = _serverServiceId;
                ht.status = _status;

                dataContext.History.InsertOnSubmit(ht);
                dataContext.SubmitChanges();

                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }       
        }

        public bool InsertRealTimeList(List<RealTime> _realTimes)
        {
            try
            {
                foreach (RealTime realTime in _realTimes)
                {
                    Linq.RealTime rt = new Linq.RealTime();
                    rt.serverService_id = realTime.ServerServiceId;
                    rt.status = realTime.Status;

                    dataContext.RealTime.InsertOnSubmit(rt);
                }

                dataContext.SubmitChanges();
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool InsertHistoryList(List<History> _history)
        {
            try
            {
                foreach (History history in _history)
                {
                    Linq.History ht = new Linq.History();
                    ht.instant = history.Instant;
                    ht.serverService_id = history.ServerServiceId;
                    ht.status = history.Status;

                    dataContext.History.InsertOnSubmit(ht);
                }

                dataContext.SubmitChanges();
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public List<RealTime> GetRealTimeServer(int _serverId)
        {

            List<RealTime> realTimesServer = new List<RealTime>();

            try
            {
                var searchServerRealTime = from realTime in dataContext.RealTime
                                           join serverServices in dataContext.ServerServices
                                           on realTime.serverService_id equals serverServices.serverService_id
                                           where serverServices.server_id == _serverId
                                           select realTime;


                if (searchServerRealTime.Count() > 0)
                {
                    foreach (var rt in searchServerRealTime)
                    {
                        realTimesServer.Add(new RealTime(rt.serverService_id, rt.status));
                    }
                }

                return realTimesServer;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public List<RealTime> GetRealTime()
        {

            List<RealTime> realTimes = new List<RealTime>();

            var searchRealTimes = from realTime in dataContext.RealTime
                                       select realTime;


            if (searchRealTimes.Count() > 0)
            {
                foreach (var rt in searchRealTimes)
                {
                    realTimes.Add(new RealTime(rt.serverService_id, rt.status));
                }
            }

            return realTimes;
        }

        public bool CopyRealTimeToHistory()
        {
            try
            {
                List<RealTime> realTimes = GetRealTime();
                List<History> history = new List<History>();

                foreach (RealTime rt in realTimes)
                {
                    history.Add(new History(DateTime.Now, rt.ServerServiceId, rt.Status));
                }

                return InsertHistoryList(history);

            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

    }
}
