﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Framework
{
    public class ServerDALImpl : IServerDAL
    {
        Framework.Linq.LinqToSqlDataContext dataContext = new Framework.Linq.LinqToSqlDataContext();
        IConfigurationDAL conf = new ConfigurationDALImpl();

        public Server GetServer(int _serverId)
        {
           
            try
            {
                Server _server = new Server();

                var searchServerById = from s in dataContext.Server
                                       where s.server_id == _serverId
                                       select s;

                if (searchServerById.Count() > 0)
                {
                    _server.Id = searchServerById.First().server_id;
                    _server.Name = searchServerById.First().name.Trim();
                    _server.Description = searchServerById.First().description.Trim();
                    _server.DnsName = searchServerById.First().dnsname.Trim();
                    _server.Ip = searchServerById.First().ip.Trim();
                    _server.ZoneId = searchServerById.First().zone_id;
                    _server.UserOwner = searchServerById.First().userOwner;
                    _server.Memory = searchServerById.First().memory;
                    _server.CPU = searchServerById.First().cpu;
                    _server.HDD = searchServerById.First().hdd;
                    _server.Critic = searchServerById.First().critic;
                    _server.StartDate = searchServerById.First().startDate;
                    if (searchServerById.First().endDate != null)
                    {
                        _server.EndDate = (DateTime)searchServerById.First().endDate;
                    }
                }
                else
                {
                    _server.Name = "No existeix";
                }
                conf.writeLog("GetServer - " + _serverId);
                return _server;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public List<Server> GetAllServers()
        {
            try
            {
                List<Server> _servers = new List<Server>();

                foreach (Linq.Server _server in dataContext.Server)
                {
                    Server _serverTmp = GetServer(_server.server_id);
                    _servers.Add(_serverTmp);
                }

                conf.writeLog("GetAllServers");
                return _servers;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public List<Server> GetAllActiveServers()
        {
            try
            {
                List<Server> _servers = new List<Server>();

                foreach (Linq.Server _server in dataContext.Server)
                {
                    Server _serverTmp = GetServer(_server.server_id);

                    //verify this server is active
                    if (_serverTmp.EndDate == new DateTime(2001, 01, 01))
                    {
                        _servers.Add(_serverTmp);
                    }
                }

                conf.writeLog("GetAllServers");
                return _servers;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public ServerZone GetServerZone(int _serverZoneId)
        {
            ServerZone _serverZone = new ServerZone();

            try
            {
                var searchServerById = from s in dataContext.ServerZone
                                       where s.zone_id == _serverZoneId
                                       select s;

                if (searchServerById.Count() > 0)
                {
                    _serverZone.Id = searchServerById.First().zone_id;
                    _serverZone.Name = searchServerById.First().name.Trim();
                }
                else
                {
                    _serverZone.Name = "No existeix";
                }

                conf.writeLog("SetServerZone - " + _serverZoneId);
                return _serverZone;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public List<ServerZone> GetAllServerZones()
        {
            List<ServerZone> _serverZones = new List<ServerZone>();

            try
            {
                var search = from sz in dataContext.ServerZone
                             select sz;

                foreach (var _sz in search)
                {
                   _serverZones.Add(new ServerZone(_sz.zone_id, _sz.name.Trim()));
                }

                conf.writeLog("GetAllServeerZones");
                return _serverZones;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public bool AddServerZone(string _zone)
        {
            try
            {
                int max = (from s in dataContext.ServerZone
                           select s.zone_id).Max();

                Linq.ServerZone zone = new Linq.ServerZone();

                zone.zone_id = max + 1;
                zone.name = _zone;

                dataContext.ServerZone.InsertOnSubmit(zone);
                dataContext.SubmitChanges();

                conf.writeLog("AddServerZone - " + _zone);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool UpdateServerZone(ServerZone _serverzone)
        {
            try
            {
                var search = from sz in dataContext.ServerZone
                             where sz.zone_id == _serverzone.Id
                             select sz;

                if (search.Count() > 0)
                {
                    Linq.ServerZone _sz = search.First();

                    _sz.zone_id = search.First().zone_id;
                    _sz.name = _serverzone.Name;

                    dataContext.SubmitChanges();
                    
                    return true;
                }

                conf.writeLog("UpdateServerZone - " + _serverzone);
                return false;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool DisableServer(string _servername)
        {
            try
            {
                var searchServer = from svr in dataContext.Server
                                 where svr.name.Equals(_servername)
                                 select svr;

                if (searchServer.Count() == 1)
                {
                    searchServer.First().endDate = DateTime.Now;
                    dataContext.SubmitChanges();
                }
                conf.writeLog("DisableServer - " + _servername);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool EnabledServer(string _servername)
        {
            try
            {
                var searchServer = from svr in dataContext.Server
                                 where svr.name.Equals(_servername)
                                 select svr;

                if (searchServer.Count() == 1)
                {
                    searchServer.First().endDate = new DateTime(2001, 01, 01);
                    dataContext.SubmitChanges();
                }

                conf.writeLog("EnabledServer - " + _servername);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public int AddServer(Server _server)
        {
            try
            {
                int max = (from s in dataContext.Server
                           select s.server_id).Max();

                Linq.Server server = new Linq.Server();

                server.server_id = max + 1;
                server.name = _server.Name;
                server.description = _server.Description;
                server.dnsname = _server.DnsName;
                server.ip = _server.Ip;
                server.zone_id = _server.ZoneId;
                server.userOwner = _server.UserOwner;
                server.memory = _server.Memory;
                server.cpu = _server.CPU;
                server.hdd = _server.HDD;
                server.critic = _server.Critic;
                server.startDate = DateTime.Now;
                server.endDate = new DateTime(2001, 01, 01);

                dataContext.Server.InsertOnSubmit(server);
                dataContext.SubmitChanges();


                //Create all serverServices

                var search = from services in dataContext.Service
                             select services;

                foreach (var service in search)
                {
                    IServerServiceDAL ss = new ServerServiceDALImpl();
                    ss.AddServerService(server.server_id, service.service_id);
                }

                conf.writeLog("AddServer - " + _server.Name);
                return max + 1;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return 0;
            }
        }

        public int EditServer(Server _server)
        {
            try
            {
                var searchServer = from svr in dataContext.Server
                                 where svr.name.Equals(_server.Name)
                                 select svr;

                Linq.Server server = searchServer.First();

                server.name = _server.Name;
                server.description = _server.Description;
                server.dnsname = _server.DnsName;
                server.ip = _server.Ip;
                server.zone_id = server.zone_id;
                server.userOwner = _server.UserOwner;
                server.memory = _server.Memory;
                server.cpu = _server.CPU;
                server.hdd = _server.HDD;
                server.critic = _server.Critic;

                dataContext.SubmitChanges();

                conf.writeLog("EditServer - " + _server.Name);
                return server.server_id;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return 0;
            }
        }
    }
}
