﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Framework
{
    public class UserDALImpl : IUserDAL
    {
        
        Linq.LinqToSqlDataContext dataContext = new Linq.LinqToSqlDataContext();
        IConfigurationDAL conf = new ConfigurationDALImpl();
        IAccessLogDAL log = new AccessLogDALImpl();

        public User GetUser(int _userId)
        {
            try
            {

                var searchUser = from usr in dataContext.User
                                 where usr.user_id.Equals(_userId)
                                 select usr;

                if (searchUser.Count() == 1)
                {
                    User _user = new User();

                    _user.UserId = _userId;
                    _user.UserName = searchUser.First().username.Trim();
                    _user.Password = searchUser.First().password.Trim();
                    _user.Name = searchUser.First().name.Trim();
                    _user.Email = searchUser.First().email.Trim();
                    _user.SendEmail = (bool) searchUser.First().sendEmail;
                    _user.Twitter = searchUser.First().twitter.Trim();
                    _user.SendTwitter = (bool)searchUser.First().sendTwitter;
                    _user.SMS = searchUser.First().sms.Trim();
                    _user.SendSMS = (bool)searchUser.First().sendSMS;
                    _user.Telephone = searchUser.First().telephone.Trim();
                    _user.GroupId = searchUser.First().group_id;
                    _user.StartDate = searchUser.First().startDate;
                    _user.EndDate = (DateTime) searchUser.First().endDate;
                    _user.Comments = searchUser.First().comments.Trim();
                    conf.writeLog( "getUser " + _user.UserName);
                    return _user;
                }

                conf.writeLog(_userId + " - getUser - Usuari no trobat");
                return null;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public User GetUser(string _username)
        {
            try
            {
                var searchUser = from usr in dataContext.User
                                 where usr.username.Equals(_username)
                                 select usr;

                if (searchUser.Count() == 1)
                {
                    User _user = new User();

                    _user.UserId = searchUser.First().user_id;
                    _user.UserName = searchUser.First().username.Trim();
                    _user.Password = searchUser.First().password.Trim();
                    _user.Name = searchUser.First().name.Trim();
                    _user.Email = searchUser.First().email.Trim();
                    _user.SendEmail = (bool)searchUser.First().sendEmail;
                    _user.Twitter = searchUser.First().twitter.Trim();
                    _user.SendTwitter = (bool)searchUser.First().sendTwitter;
                    _user.SMS = searchUser.First().sms.Trim();
                    _user.SendSMS = (bool)searchUser.First().sendSMS;
                    _user.Telephone = searchUser.First().telephone.Trim();
                    _user.GroupId = searchUser.First().group_id;
                    _user.StartDate = searchUser.First().startDate;
                    _user.EndDate = (DateTime)searchUser.First().endDate;
                    _user.Comments = searchUser.First().comments.Trim();

                    conf.writeLog("getUser" + _user.Name);
                    return _user;
                }

                conf.writeLog(_username + " - getUser - Usuari no trobat");
                return null;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public bool VerifyUser(string _username, string _password)
        {
            try
            {

                var searchUser = from usr in dataContext.User
                                 where usr.username.Equals(_username)
                                    && usr.password.Equals(_password)
                                 select usr;

                if (searchUser.Count() == 1)
                {
                    if (!searchUser.First().endDate.Equals(new DateTime(2001, 01, 01)))
                        return false;

                    conf.writeLog("VerifyUser Ok " + _username);
                    return true;
                }

                log.InsertAccessLogSystem("Intent d'accés amb l'usuari" + _username);                     
                conf.writeLog("VerifyUser KO " + _username);

                return false;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool ChangePassword(string _username, string _password)
        {
            try
            {
                var searchUser = from usr in dataContext.User
                                 where usr.username.Equals(_username)
                                 select usr;

                if (searchUser.Count() == 1)
                {
                    searchUser.First().password = _password;
                    dataContext.SubmitChanges();
                }

                conf.writeLog("ChangePassword Ok " + _username);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public List<User> GetAllUsers()
        {
            List<User> _users = new List<User>();
            try
            {
                foreach (Linq.User _user in dataContext.User)
                {
                    User _userTmp = GetUser(_user.user_id);
                    _users.Add(_userTmp);
                }

                conf.writeLog("getAllUsers");
                return _users;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public List<UserGroup> GetAllUserGroups()
        {
            try
            {
                List<UserGroup> userGroups = new List<UserGroup>();

                foreach (Linq.UserGroup _userGroup in dataContext.UserGroup)
                {
                    UserGroup _userGroupTmp = GetUserGroup(_userGroup.group_id);
                    userGroups.Add(_userGroupTmp);
                }

                conf.writeLog("getAllUserGroups");
                return userGroups;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public UserGroup GetUserGroup(int _groupId)
        {
            try
            {
                UserGroup _userGroup = new UserGroup();

                var searchUserGroupById = from s in dataContext.UserGroup
                                          where s.group_id.Equals(_groupId)
                                          select s;

                if (searchUserGroupById.Count() > 0)
                {
                    _userGroup.GroupId = searchUserGroupById.First().group_id;
                    _userGroup.Name = searchUserGroupById.First().name.Trim();
                    
                    return _userGroup;
                }
                return null;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public bool AddUserGroup(string _group)
        {
            try
            {

                int max = (from s in dataContext.UserGroup
                           select s.group_id).Max();

                Linq.UserGroup group = new Linq.UserGroup();

                group.group_id = max + 1;
                group.name= _group;

                dataContext.UserGroup.InsertOnSubmit(group);
                dataContext.SubmitChanges();

                conf.writeLog("AddUserGroup - " + _group);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool UpdateUserGroup(UserGroup _group)
        {
            try
            {
                var search = from sz in dataContext.UserGroup
                             where sz.group_id == _group.GroupId
                             select sz;

                if (search.Count() > 0)
                {
                    Linq.UserGroup ug = search.First();

                    ug.group_id = search.First().group_id;
                    ug.name = _group.Name;

                    dataContext.SubmitChanges();

                    conf.writeLog("UpdateUserGroup - " + _group);
                    return true;
                }

                return false;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool DisableUser(string _username)
        {
            try
            {
                var searchUser = from usr in dataContext.User
                                 where usr.username.Equals(_username)
                                 select usr;

                if (searchUser.Count() == 1)
                {
                    searchUser.First().endDate = DateTime.Now;
                    dataContext.SubmitChanges();
                }


                conf.writeLog("DisableUser - " + _username);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool EnabledUser(string _username)
        {
            try
            {
                var searchUser = from usr in dataContext.User
                                 where usr.username.Equals(_username)
                                 select usr;

                if (searchUser.Count() == 1)
                {
                    searchUser.First().endDate = new DateTime(2001,01,01);
                    dataContext.SubmitChanges();
                }


                conf.writeLog("EnabledUser - " + _username);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool AddUser(User _user)
        {

            try
            {

                int max = (from u in dataContext.User
                           select u.user_id).Max();

                Linq.User user = new Linq.User();

                user.user_id = max + 1;
                user.name = _user.Name;
                user.username = _user.UserName;
                user.password = _user.Password;
                user.email = _user.Email;
                user.sendEmail = _user.SendEmail;
                user.twitter = _user.Twitter;
                user.sendTwitter = _user.SendTwitter;
                user.sms = _user.SMS;
                user.sendSMS = _user.SendSMS;
                user.telephone = _user.Telephone;
                user.group_id = _user.GroupId;
                user.startDate = DateTime.Now;
                user.endDate = new DateTime(2001, 01, 01);
                user.comments = _user.Comments;

                dataContext.User.InsertOnSubmit(user);
                dataContext.SubmitChanges();

                conf.writeLog("AddUser - " + _user.UserName);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        public bool EditUser(User _user)
        {

            try
            {

                var searchUser = from usr in dataContext.User
                                 where usr.username.Equals(_user.UserName)
                                 select usr;

                Linq.User user = searchUser.First();

                user.name = _user.Name;
                user.username = _user.UserName;
                if (_user.Password != null)
                {
                    user.password = _user.Password;
                }
                else
                {
                    user.password = searchUser.First().password;
                }
                user.email = _user.Email;
                user.sendEmail = _user.SendEmail;
                user.twitter = _user.Twitter;
                user.sendTwitter = _user.SendTwitter;
                user.sms = _user.SMS;
                user.sendSMS = _user.SendSMS;
                user.telephone = _user.Telephone;
                user.group_id = _user.GroupId;
                user.comments = _user.Comments;

                dataContext.SubmitChanges();

                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        #region Permissions
        
        public List<User> GetUsersPermissionToServerService(int _serverServiceId)
        {
            try
            {
                List<User> _users = new List<User>();

                var _search = from users in dataContext.User
                              join permissions in dataContext.Permissions
                              on users.user_id equals permissions.user_id
                              where permissions.serverService_id == _serverServiceId
                              select users;


                foreach (var user in _search)
                {
                    if (user.endDate < DateTime.Today)
                    {
                        _users.Add(new User(user.user_id, user.username,
                                            user.name, user.email,
                                            (bool) user.sendEmail, user.twitter,
                                            (bool)user.sendTwitter, user.sms, 
                                            (bool)user.sendSMS, user.telephone));
                    }
                }

                return _users;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            }
        }

        public bool UpdatePermissions(int _userId, List<int> _unassigned, List<int> _assigned)
        {
            try
            {
                //First delete all _unassigned permissions if exists
                if (_unassigned.Count > 0)
                {                   

                    foreach (int ss in _unassigned)
                    {
                        
                        var search = from p in dataContext.Permissions
                             where p.user_id == _userId
                                && p.serverService_id == ss
                             select p;


                        if (search.Count() > 0)
                        {
                            dataContext.Permissions.DeleteOnSubmit(search.First());
                            dataContext.SubmitChanges();
                        }
                    }
                }

                //After all _assigned permissions if exists
                if (_assigned.Count > 0)
                {

                    foreach (int ss in _assigned)
                    {

                        var search = from p in dataContext.Permissions
                                     where p.user_id == _userId
                                        && p.serverService_id == ss
                                     select p;


                        if (search.Count() == 0)
                        {
                            Linq.Permissions tmp = new Linq.Permissions();
                            tmp.serverService_id = ss;
                            tmp.user_id = _userId;

                            dataContext.Permissions.InsertOnSubmit(tmp);
                            dataContext.SubmitChanges();
                        }
                    
                    }
                }

                conf.writeLog("UpdatePermissions - UserId: " + _userId);
                return true;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return false;
            }
        }

        #endregion

    }
}
