﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;


namespace Framework
{
    public class ViewDAL : IViewDAL
    {
        Framework.Linq.LinqToSqlDataContext dataContext = new Framework.Linq.LinqToSqlDataContext();
        IConfigurationDAL conf = new ConfigurationDALImpl();

        public List<vAlerts> GetAlarmsUnreadByUserId(int _userId)
        {
            try
            {
                List<vAlerts> alerts = new List<vAlerts>();

                var search = from _alerts in dataContext.GetAlarmsUnreadByUserId(_userId)
                             select _alerts;

                foreach (var alert in search)
                {
                    alerts.Add(new vAlerts(alert.Id, alert.Status, alert.Server, alert.Service, alert.Instant));
                }

                return alerts;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }

        public vAlert GetAlarm(int _alarmId)
        {
            try
            {
                vAlert alert = new vAlert();

                var search = from _alerts in dataContext.GetAlarm(_alarmId)
                             select _alerts;

                if (search.Count() > 0)
                {
                    alert.Id = _alarmId;
                    alert.Server = search.First().ServerName;
                    alert.ServerAlerts = (int) search.First().ServerAlerts;
                    alert.Service = search.First().ServiceName;
                    alert.ServiceAlerts = (int) search.First().ServiceAlerts;
                    alert.OwnerName = search.First().Owner;
                    alert.OwnerEmail = search.First().Email;
                    alert.OwnerTlf = search.First().Phone;

                    //Depending on the type of service and alert levels
                    //will return a 0 if it is down and 1 if it is Ok.

                    if (search.First().ServiceId <= 101)
                    {
                        alert.Actually = (int)search.First().Actually;
                    }
                    else
                    {
                        IConfigurationDAL _conf = new ConfigurationDALImpl();
                        int _actually = 1;
                        switch ((int)search.First().ServiceId)
                        {

                            case 102:
                                if ((int)search.First().Actually > _conf.GetMaxMemoryUsage() )
                                    _actually = 0;
                                break;

                            case 103:
                                goto case 106;      
                            case 104:
                                goto case 106;
                            case 105:
                                goto case 106;
                            case 106:
                                if ((int)search.First().Actually > 95)
                                    _actually = 0;
                                break;

                            case 107:
                                goto case 110;
                            case 108:
                                goto case 110;
                            case 109:
                                goto case 110;
                            case 110:
                                if ((int)search.First().Actually > _conf.GetMaxHddUsage())
                                    _actually = 0;
                                break;

                            default:
                                _actually = 0;
                                break;
                        }

                        alert.Actually = _actually;
                    }
                    alert.Solution = search.First().Solution;
                    alert.Instant = search.First().Instant;
                    alert.Status = search.First().Status;
                }

                return alert;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }

        public List<vServers> GetServersByUserId(int _userId)
        {
            try
            {
                List<vServers> servers = new List<vServers>();
                var search = from _servers in dataContext.GetServers(_userId)
                             select _servers;

                foreach (var server in search)
                {
                    int status = 0;
                    DateTime lastAlarm = new DateTime(0);

                    if (!server.Status.Equals(null))
                    {
                        status = (int) server.Status;
                    }

                    if (!server.LastAlarm.Equals(null))
                    {
                        lastAlarm = (DateTime)server.LastAlarm;
                    }

                    servers.Add(new vServers(server.ServerId, status, server.Name,
                                                 server.Zone, (int)server.CurrentAlarms, (int)server.ServerAlarms,
                                                 server.Critic, lastAlarm));
                }

                return servers;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }

        public vServer GetViewServer(int _serverId, int _userId)
        {
            try
            {            
                vServer server = new vServer();
                var search = from _servers in dataContext.GetServer(_serverId, _userId)
                             select _servers;

                if (search.Count() > 0)
                {
                    server.Id = _serverId;
                    server.Name = search.First().Name;
                    server.Zone = search.First().Zone;
                    server.CurrentAlarms = (int) search.First().CurrentAlarms;
                    server.DNS = search.First().ServerDNS;
                    server.Critic = search.First().Critic;
                    server.TotalAlarms = (int) search.First().ServerAlarms;
                    server.IP = search.First().ServerIP;
                    server.Description = search.First().Description;
                    server.OwnerId = (int) search.First().OwnerId;
                    server.OwnerName = search.First().OwnerName;
                    server.OwnerEmail = search.First().OwnerEmail;
                    server.OwnerPhone = search.First().OwnerPhone;
                    if (search.First().LastAlarm != null)
                    {
                        server.LastAlarm = (DateTime)search.First().LastAlarm;
                    }
                    else
                    {
                        server.LastAlarm = new DateTime(0);
                    }
                }

                return server;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }

        public List<vRealTimeServer> GetViewRealTimeServer(int _serverId, int _userId)
        {
            try
            {      
                List<vRealTimeServer> server = new List<vRealTimeServer>();
                var search = from _rt in dataContext.GetRealTimeServer(_serverId, _userId)
                             select _rt;

                if (search.Count() > 0)
                {
                    foreach (var service in search)
                    {
                        vRealTimeServer rt = new vRealTimeServer();
                        rt.ServiceId = service.ServiceId;
                        rt.ServiceName = service.Name;
                        rt.Status = service.Status;

                        switch (service.ServiceId)
                        {
                            case 102:
                                rt.MaxValue = conf.GetMaxMemoryUsage();
                                break;

                            case 103:
                                goto case 106;
                            case 104:
                                goto case 106;
                            case 105:
                                goto case 106;
                            case 106:
                                rt.MaxValue = 90;
                                break;
                            case 107:
                                goto case 110;
                            case 108:
                                goto case 110;
                            case 109:
                                goto case 110;
                            case 110:
                                rt.MaxValue = conf.GetMaxHddUsage();
                                break;

                            default:
                                rt.MaxValue = 1;
                                break;
                        }
                        server.Add(rt);
                    }
                }

                return server;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }

        public List<vUsers> GetViewUsers()
        {
            try
            {
                List<vUsers> users = new List<vUsers>();
                
                var search = from _users in dataContext.GetUsersList()
                             select _users;

                foreach (var user in search)
                {
                    users.Add(new vUsers(user.Id, user.Name, user.Group,
                                         user.Username, (DateTime)user.Inactive));
                }

                return users;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }

        public List<vPermission> GetServicesUnassigned(int _serverId, int _userId)
        {
            try
            {
                List<vPermission> permissions = new List<vPermission>();

                var search = from _permissions in dataContext.GetPermissionsUnassigmentByServerForUser(_serverId, _userId)
                             select _permissions;

                foreach (var permission in search)
                {
                    permissions.Add(new vPermission(permission.Id, permission.Name));
                }

                return permissions;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }

        public List<vPermission> GetServicesAssigned(int _serverId, int _userId)
        {
            List<vPermission> permissions = new List<vPermission>();

            try
            {

                var search = from _permissions in dataContext.GetPermissionsAssigmentByServerForUser(_serverId, _userId)
                             select _permissions;

                foreach (var permission in search)
                {
                    permissions.Add(new vPermission(permission.Id, permission.Name));
                }

                return permissions;
            }
            catch
            {
                return null;
            }
        }

        public List<vServerList> GetViewServerList(int _userId)
        {
            try
            {
                List<vServerList> servers = new List<vServerList>();

                var search = from _servers in dataContext.GetViewServerList(_userId)
                             select _servers;

                foreach (var server in search)
                {
                    servers.Add(new vServerList(server.ServerId, server.Name, server.Zone, server.Critic,
                                                (DateTime) server.Inactive, (int) server.ServerAlarms));
                }

                return servers;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }

        public List<vHistory> GetHistoryByServerServiceId(int _serverId, int _serviceId)
        {
            try
            {
                List<vHistory> history = new List<vHistory>();
                
                var search = from _history in dataContext.GetHistoryByServerServiceId(_serverId, _serviceId)
                             select _history;

                foreach (var tmp in search)
                {
                    history.Add(new vHistory(tmp.instant, tmp.status));
                }

                return history;
            }
            catch (Exception e)
            {
                conf.writeLog(e.Message);
                return null;
            } 
        }
    }
}
