/****************************************/
/****************************************/
/******                            ******/
/******       Server Monitor       ******/
/****** UOC - TFC - Oriol Foradada ******/
/******         June 2012          ******/
/******                            ******/
/****************************************/
/****************************************/


/************************************************/
/****** Verify if exist database and user *******/
/******       If exist, delete both       *******/
/************************************************/

USE [master]
GO

IF  EXISTS (SELECT name FROM sys.databases WHERE name = N'ServerMonitor')
   	    DROP DATABASE [ServerMonitor]
GO

IF  EXISTS (SELECT * FROM sys.server_principals WHERE name = N'appMonitor')
	    DROP LOGIN [appMonitor]
GO



/*****************************/
/****** Create DataBase ******/
/*****************************/

CREATE DATABASE [ServerMonitor]
GO
ALTER DATABASE [ServerMonitor] SET COMPATIBILITY_LEVEL = 100
GO
ALTER DATABASE [ServerMonitor] SET ANSI_NULL_DEFAULT OFF 
GO
ALTER DATABASE [ServerMonitor] SET ANSI_NULLS OFF 
GO
ALTER DATABASE [ServerMonitor] SET ANSI_PADDING OFF 
GO
ALTER DATABASE [ServerMonitor] SET ANSI_WARNINGS OFF 
GO
ALTER DATABASE [ServerMonitor] SET ARITHABORT OFF 
GO
ALTER DATABASE [ServerMonitor] SET AUTO_CLOSE OFF 
GO
ALTER DATABASE [ServerMonitor] SET AUTO_CREATE_STATISTICS ON 
GO
ALTER DATABASE [ServerMonitor] SET AUTO_SHRINK OFF 
GO
ALTER DATABASE [ServerMonitor] SET AUTO_UPDATE_STATISTICS ON 
GO
ALTER DATABASE [ServerMonitor] SET CURSOR_CLOSE_ON_COMMIT OFF 
GO
ALTER DATABASE [ServerMonitor] SET CURSOR_DEFAULT  GLOBAL 
GO
ALTER DATABASE [ServerMonitor] SET CONCAT_NULL_YIELDS_NULL OFF 
GO
ALTER DATABASE [ServerMonitor] SET NUMERIC_ROUNDABORT OFF 
GO
ALTER DATABASE [ServerMonitor] SET QUOTED_IDENTIFIER OFF 
GO
ALTER DATABASE [ServerMonitor] SET RECURSIVE_TRIGGERS OFF 
GO
ALTER DATABASE [ServerMonitor] SET  DISABLE_BROKER 
GO
ALTER DATABASE [ServerMonitor] SET AUTO_UPDATE_STATISTICS_ASYNC OFF 
GO
ALTER DATABASE [ServerMonitor] SET DATE_CORRELATION_OPTIMIZATION OFF 
GO
ALTER DATABASE [ServerMonitor] SET PARAMETERIZATION SIMPLE 
GO
ALTER DATABASE [ServerMonitor] SET  READ_WRITE 
GO
ALTER DATABASE [ServerMonitor] SET RECOVERY SIMPLE 
GO
ALTER DATABASE [ServerMonitor] SET  MULTI_USER 
GO
ALTER DATABASE [ServerMonitor] SET PAGE_VERIFY CHECKSUM  
GO
USE [ServerMonitor]
GO
IF NOT EXISTS (SELECT name FROM sys.filegroups WHERE is_default=1 AND name = N'PRIMARY') ALTER DATABASE [ServerMonitor] MODIFY FILEGROUP [PRIMARY] DEFAULT
GO


/*************************/
/****** Create User ******/
/*************************/

USE [master]
GO
CREATE LOGIN [appMonitor] WITH PASSWORD=N'TFC-@2012-Monitor', DEFAULT_DATABASE=[ServerMonitor], CHECK_EXPIRATION=OFF, CHECK_POLICY=ON
GO
	USE [ServerMonitor]
GO
CREATE USER [appMonitor] FOR LOGIN [appMonitor]
GO
USE [ServerMonitor]
GO
ALTER USER [appMonitor] WITH DEFAULT_SCHEMA=[dbo]
GO
USE [ServerMonitor]
GO
EXEC sp_addrolemember N'db_owner', N'appMonitor'
GO

/***************************/
/****** Create Tables ******/
/***************************/


/****** Create Table UserGroup ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[UserGroup](
	[group_id] [int] NOT NULL,
	[name] [nchar](100) NOT NULL,
 CONSTRAINT [PK_UserGroup] PRIMARY KEY CLUSTERED 
(
	[group_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'List of user groups' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'UserGroup'
GO



/****** Create Table Service ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Service](
	[service_id] [int] NOT NULL,
	[name] [nchar](100) NOT NULL,
	[description] [nchar](255) NULL,
	[resolution] [nchar](255) NULL,
 CONSTRAINT [PK_Service] PRIMARY KEY CLUSTERED 
(
	[service_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Enumeration of services to analyze' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Service'
GO


/****** Create Table ServerZone ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ServerZone](
	[zone_id] [int] NOT NULL,
	[name] [nchar](100) NOT NULL,
 CONSTRAINT [PK_ServerZone] PRIMARY KEY CLUSTERED 
(
	[zone_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Zones of server' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ServerZone'
GO



/****** Create Table RealTime ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[RealTime](
	[serverService_id] [int] NOT NULL,
	[status] [int] NOT NULL,
 CONSTRAINT [PK_RealTime] PRIMARY KEY CLUSTERED 
(
	[serverService_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Current status of the services associated to servers' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'RealTime'
GO


/****** Create Table Configuration ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Configuration](
	[conf_id] [int] NOT NULL,
	[domainAdminUser] [nchar](100) NULL,
	[domainPwdUser] [nchar](100) NULL,
	[domain] [nchar](100) NULL,
	[serverSMTP] [nchar](100) NOT NULL,
	[userSMTP] [nchar](100) NULL,
	[pwdSMTP] [nchar](100) NULL,
	[timeUpdate] [int] NOT NULL,
	[maxTimeCPU] [int] NOT NULL,
	[maxMemoryUsage] [int] NOT NULL,
	[maxHddUsage] [int] NOT NULL,
	[maxTimeOut] [int] NOT NULL,
	[logPath] [nchar] (250) NOT NULL,
CONSTRAINT [PK_Configuration] PRIMARY KEY CLUSTERED 
(
	[conf_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
)ON [PRIMARY]

GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'seconds' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Configuration', @level2type=N'COLUMN',@level2name=N'timeUpdate'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'minutes' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Configuration', @level2type=N'COLUMN',@level2name=N'maxTimeCPU'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'percent' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Configuration', @level2type=N'COLUMN',@level2name=N'maxMemoryUsage'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'percent' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Configuration', @level2type=N'COLUMN',@level2name=N'maxHddUsage'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'failed connctions' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Configuration', @level2type=N'COLUMN',@level2name=N'maxTimeOut'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Configuration information of the application. Will always be a single line. Fields created by default and only perform updates.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Configuration'
GO



/****** Create Table Server ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Server](
	[server_id] [int] NOT NULL,
	[name] [nchar](100) NOT NULL,
	[description] [nchar](255) NULL,
	[dnsname] [nchar](100) NULL,
	[ip] [nchar](15) NULL,
	[zone_id] [int] NOT NULL,
	[userOwner] [int] NOT NULL,
	[memory] [int] NOT NULL,
	[cpu] [int] NOT NULL,
	[hdd] [int] NOT NULL,
	[critic] [bit] NOT NULL,
	[startDate] [datetime] NOT NULL,
	[endDate] [datetime] NULL
 CONSTRAINT [PK_Server] PRIMARY KEY CLUSTERED 
(
	[server_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Server list' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Server'
GO



/****** Create Table User ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[User](
	[user_id] [int] NOT NULL,
	[username] [nchar](100) NOT NULL,
	[password] [nchar](100) NOT NULL,
	[name] [nchar](150) NULL,
	[email] [nchar](100) NULL,
	[sendEmail] [bit] NULL,
	[twitter] [nchar](16) NULL,
	[sendTwitter] [bit] NULL,
	[sms] [nchar](9) NULL,
	[sendSMS] [bit] NULL,
	[telephone] [nchar](15) NULL,
	[group_id] [int] NOT NULL,
	[startDate] [datetime] NOT NULL,
	[endDate] [datetime] NULL,
	[comments] [nchar](255) NULL,
 CONSTRAINT [PK_User] PRIMARY KEY CLUSTERED 
(
	[user_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Users of the application' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'User'
GO


/****** Create Table AccessLog******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[AccessLog](
	[instant] [datetime] NOT NULL,
	[user_id] [int] NOT NULL,
	[action] [nchar](255) NULL
 CONSTRAINT [PK_AccessLog] PRIMARY KEY CLUSTERED
(
	[instant] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Logs of users actions' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'AccessLog'
GO


/****** Create Table ServerServices ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[ServerServices](
	[serverService_id] [int] NOT NULL,
	[server_id] [int] NOT NULL,
	[service_id] [int] NOT NULL,
	[status] [int] NOT NULL,
 CONSTRAINT [PK_ServerServices] PRIMARY KEY CLUSTERED 
(
	[serverService_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Relation of the services associated to servers' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'ServerServices'
GO


/****** Create Table Alarm ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Alarm](
	[alarm_id] [int] NOT NULL,
	[instant] [datetime] NOT NULL,
	[serverService_id] [int] NOT NULL,
	[user_id] [int] NOT NULL,
	[status] [int] NOT NULL,
 CONSTRAINT [PK_Alarm] PRIMARY KEY CLUSTERED 
(
	[alarm_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'List of alarms' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Alarm'
GO


/****** Create Table Permissions ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Permissions](
	[serverService_id] [int] NOT NULL,
	[user_id] [int] NOT NULL,
 CONSTRAINT [PK_Permissions] PRIMARY KEY CLUSTERED 
(
	[serverService_id] ASC,
	[user_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Relation of permissions of users than services of servers' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'Permissions'
GO


/****** Create Table History ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[History](
	[instant] [datetime] NOT NULL,
	[serverService_id] [int] NOT NULL,
	[status] [int] NOT NULL,
 CONSTRAINT [PK_History] PRIMARY KEY CLUSTERED 
(
	[instant] ASC,
	[serverService_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'History of events produced' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'History'
GO


/****** Alter Tables ******/

/****** Object:  Default [DF_AccessLog_instant]   ******/
ALTER TABLE [dbo].[AccessLog] ADD  CONSTRAINT [DF_AccessLog_instant]  DEFAULT (getdate()) FOR [instant]
GO

/****** Object:  Default [DF_Alarm_instant]   ******/
ALTER TABLE [dbo].[Alarm] ADD  CONSTRAINT [DF_Alarm_instant]  DEFAULT (getdate()) FOR [instant]
GO

/****** Object:  Default [DF_History_instant]   ******/
ALTER TABLE [dbo].[History] ADD  CONSTRAINT [DF_History_instant]  DEFAULT (getdate()) FOR [instant]
GO

/****** Object:  Default [DF_Server_startDate]   ******/
ALTER TABLE [dbo].[Server] ADD  CONSTRAINT [DF_Server_startDate]  DEFAULT (getdate()) FOR [startDate]
GO

/****** Object:  Default [DF_User_startDate]   ******/
ALTER TABLE [dbo].[User] ADD  CONSTRAINT [DF_User_startDate]  DEFAULT (getdate()) FOR [startDate]
GO

/****** Object:  Default [DF_User_sendEmail]   ******/
ALTER TABLE [dbo].[User] ADD  CONSTRAINT [DF_User_sendEmail]  DEFAULT (0) FOR [sendEmail]
GO

/****** Object:  Default [DF_User_sendTwitter]   ******/
ALTER TABLE [dbo].[User] ADD  CONSTRAINT [DF_User_sendTwitter]  DEFAULT (0) FOR [sendTwitter]
GO

/****** Object:  Default [DF_User_sendSMS]   ******/
ALTER TABLE [dbo].[User] ADD  CONSTRAINT [DF_User_sendSMS]  DEFAULT (0) FOR [sendSMS]
GO

/****** Object:  Default [DF_ServerServices_status]   ******/
ALTER TABLE [dbo].[ServerServices] ADD  CONSTRAINT [DF_ServerServices_status]  DEFAULT (0) FOR [status]
GO

/****** Object:  Default [UC_User_username]   ******/
ALTER TABLE [dbo].[User] ADD  CONSTRAINT [UC_User_username]  UNIQUE (username)
GO

/****** Object:  Default [UC_Server_name]   ******/
ALTER TABLE [dbo].[Server] ADD  CONSTRAINT [UC_Server_name]  UNIQUE (name)
GO

/****** Object:  Default [UC_ServerZone_name]   ******/
ALTER TABLE [dbo].[ServerZone] ADD  CONSTRAINT [UC_ServerZone_name]  UNIQUE (name)
GO

/****** Object:  Default [UC_UserGroup_name]   ******/
ALTER TABLE [dbo].[UserGroup] ADD  CONSTRAINT [UC_UserGroup_name]  UNIQUE (name)
GO

/****** Object:  Default [UC_Service_name]   ******/
ALTER TABLE [dbo].[Service] ADD  CONSTRAINT [UC_Service_name]  UNIQUE (name)
GO

/****** Object:  Default [DF_Configuration_timeUpdate]  ******/
ALTER TABLE [dbo].[Configuration] ADD  CONSTRAINT [DF_Configuration_timeUpdate]  DEFAULT ((5)) FOR [timeUpdate]
GO

/****** Object:  Default [DF_Configuration_maxTimeCPU]  ******/
ALTER TABLE [dbo].[Configuration] ADD  CONSTRAINT [DF_Configuration_maxTimeCPU]  DEFAULT ((5)) FOR [maxTimeCPU]
GO

/****** Object:  Default [DF_Configuration_maxMemoryUsage]  ******/
ALTER TABLE [dbo].[Configuration] ADD  CONSTRAINT [DF_Configuration_maxMemoryUsage]  DEFAULT ((90)) FOR [maxMemoryUsage]
GO

/****** Object:  Default [DF_Configuration_maxHddUsage]  ******/
ALTER TABLE [dbo].[Configuration] ADD  CONSTRAINT [DF_Configuration_maxHddUsage]  DEFAULT ((90)) FOR [maxHddUsage]
GO

/****** Object:  Default [DF_Configuration_maxTimeOut]   ******/
ALTER TABLE [dbo].[Configuration] ADD  CONSTRAINT [DF_Configuration_maxTimeOut]  DEFAULT ((5)) FOR [maxTimeOut]
GO

/****** Object:  Default [FK_Server_User]  ******/
ALTER TABLE [dbo].[Server]  WITH CHECK ADD  CONSTRAINT [FK_Server_User] FOREIGN KEY([userOwner])
REFERENCES [dbo].[User] ([user_id])
GO

ALTER TABLE [dbo].[Server] CHECK CONSTRAINT [FK_Server_User]
GO

/****** Object:  Default [DF_Server_cpu]  ******/
ALTER TABLE [dbo].[Server] ADD  CONSTRAINT [DF_Server_cpu]  DEFAULT ((1)) FOR [cpu]
GO

/****** Object:  Default [DF_Server_hdd]   ******/
ALTER TABLE [dbo].[Server] ADD  CONSTRAINT [DF_Server_hdd]  DEFAULT ((1)) FOR [hdd]
GO

/****** Object:  Default [DF_Server_critic]   ******/
ALTER TABLE [dbo].[Server] ADD  CONSTRAINT [DF_Server_critic]  DEFAULT ((0)) FOR [critic]
GO

/****** Object:  ForeignKey [FK_AccessLog_User]  ******/
ALTER TABLE [dbo].[AccessLog]  WITH CHECK ADD  CONSTRAINT [FK_AccessLog_User] FOREIGN KEY([user_id])
REFERENCES [dbo].[User] ([user_id])
GO

ALTER TABLE [dbo].[AccessLog] CHECK CONSTRAINT [FK_AccessLog_User]
GO

/****** Object:  ForeignKey [FK_Alarm_ServerServices]  ******/
ALTER TABLE [dbo].[Alarm]  WITH CHECK ADD  CONSTRAINT [FK_Alarm_ServerServices] FOREIGN KEY([serverService_id])
REFERENCES [dbo].[ServerServices] ([serverService_id])
GO

ALTER TABLE [dbo].[Alarm] CHECK CONSTRAINT [FK_Alarm_ServerServices]
GO

/****** Object:  ForeignKey [FK_Alarm_User]  ******/
ALTER TABLE [dbo].[Alarm]  WITH CHECK ADD  CONSTRAINT [FK_Alarm_User] FOREIGN KEY([user_id])
REFERENCES [dbo].[User] ([user_id])
GO
ALTER TABLE [dbo].[Alarm] CHECK CONSTRAINT [FK_Alarm_User]
GO

/****** Object:  ForeignKey [FK_History_ServerServices]   ******/
ALTER TABLE [dbo].[History]  WITH CHECK ADD  CONSTRAINT [FK_History_ServerServices] FOREIGN KEY([serverService_id])
REFERENCES [dbo].[ServerServices] ([serverService_id])
GO
ALTER TABLE [dbo].[History] CHECK CONSTRAINT [FK_History_ServerServices]
GO

/****** Object:  ForeignKey [FK_Permissions_ServerServices]   ******/
ALTER TABLE [dbo].[Permissions]  WITH CHECK ADD  CONSTRAINT [FK_Permissions_ServerServices] FOREIGN KEY([serverService_id])
REFERENCES [dbo].[ServerServices] ([serverService_id])
GO
ALTER TABLE [dbo].[Permissions] CHECK CONSTRAINT [FK_Permissions_ServerServices]
GO

/****** Object:  ForeignKey [FK_Permissions_User]  ******/
ALTER TABLE [dbo].[Permissions]  WITH CHECK ADD  CONSTRAINT [FK_Permissions_User] FOREIGN KEY([user_id])
REFERENCES [dbo].[User] ([user_id])
GO
ALTER TABLE [dbo].[Permissions] CHECK CONSTRAINT [FK_Permissions_User]
GO

/****** Object:  ForeignKey [FK_Server_ServerZone]  ******/
ALTER TABLE [dbo].[Server]  WITH CHECK ADD  CONSTRAINT [FK_Server_ServerZone] FOREIGN KEY([zone_id])
REFERENCES [dbo].[ServerZone] ([zone_id])
GO
ALTER TABLE [dbo].[Server] CHECK CONSTRAINT [FK_Server_ServerZone]
GO

/****** Object:  ForeignKey [FK_RealTime_ServerServices]   ******/
ALTER TABLE [dbo].[RealTime]  WITH CHECK ADD  CONSTRAINT [FK_RealTime_ServerServices] FOREIGN KEY([serverService_id])
REFERENCES [dbo].[ServerServices] ([serverService_id])
GO
ALTER TABLE [dbo].[RealTime] CHECK CONSTRAINT [FK_RealTime_ServerServices]
GO

/****** Object:  ForeignKey [FK_ServerServices_Server]   ******/
ALTER TABLE [dbo].[ServerServices]  WITH CHECK ADD  CONSTRAINT [FK_ServerServices_Server] FOREIGN KEY([server_id])
REFERENCES [dbo].[Server] ([server_id])
GO
ALTER TABLE [dbo].[ServerServices] CHECK CONSTRAINT [FK_ServerServices_Server]
GO

/****** Object:  ForeignKey [FK_ServerServices_Service]   ******/
ALTER TABLE [dbo].[ServerServices]  WITH CHECK ADD  CONSTRAINT [FK_ServerServices_Service] FOREIGN KEY([service_id])
REFERENCES [dbo].[Service] ([service_id])
GO
ALTER TABLE [dbo].[ServerServices] CHECK CONSTRAINT [FK_ServerServices_Service]
GO

/****** Object:  ForeignKey [FK_User_UserGroup]   ******/
ALTER TABLE [dbo].[User]  WITH CHECK ADD  CONSTRAINT [FK_User_UserGroup] FOREIGN KEY([group_id])
REFERENCES [dbo].[UserGroup] ([group_id])
GO
ALTER TABLE [dbo].[User] CHECK CONSTRAINT [FK_User_UserGroup]
GO

/****************************************/
/****************************************/
/******                            ******/
/******       Server Monitor       ******/
/****** UOC - TFC - Oriol Foradada ******/
/******         June 2012          ******/
/******                            ******/
/****************************************/
/****************************************/


/******************************/
/****** INSERT FUNCTIONS ******/
/******************************/


/****** View Users List ******/
USE [ServerMonitor]
GO


CREATE FUNCTION dbo.GetUsersList()
RETURNS TABLE
AS
	RETURN SELECT   dbo.[User].user_id AS Id, dbo.[User].name AS Name, dbo.UserGroup.name AS [Group], dbo.[User].endDate AS Inactive, dbo.[User].username AS Username
			 FROM   dbo.[User] INNER JOIN
							    dbo.UserGroup ON dbo.[User].group_id = dbo.UserGroup.group_id
			WHERE     (dbo.[User].user_id > 0)

GO



CREATE FUNCTION dbo.GetAlarmsUnreadByUserId(@userID int)
RETURNS TABLE
AS
	RETURN SELECT    dbo.[Alarm].alarm_id AS Id, dbo.[Alarm].status AS 'Status', dbo.[Server].name AS 'Server', dbo.[Service].name AS 'Service', dbo.[Alarm].instant AS 'Instant'
			 FROM     dbo.Alarm INNER JOIN
									dbo.[ServerServices] ON [dbo].[Alarm].[serverService_id] = dbo.[ServerServices].serverService_id 
								INNER JOIN
									dbo.[Server] ON dbo.[ServerServices].server_id = dbo.[Server].server_id
								INNER JOIN
									dbo.[Service] ON dbo.[ServerServices].service_id = dbo.[Service].service_id
WHERE     (dbo.Alarm.status = 0) AND (dbo.Alarm.user_id = @userId)
GO

CREATE FUNCTION dbo.GetAlarm(@alarmID int)
RETURNS TABLE
AS
	RETURN SELECT     dbo.Server.name AS ServerName,
                          (SELECT     COUNT(*) AS Expr1
                            FROM          dbo.Alarm AS Alarm_1 INNER JOIN
                                                   dbo.ServerServices AS ServerServices_1 ON Alarm_1.serverService_id = ServerServices_1.serverService_id INNER JOIN
                                                   dbo.Server AS Server_1 ON ServerServices_1.server_id = Server_1.server_id
                            WHERE      (Server_1.server_id = dbo.Server.server_id) AND (Alarm_1.user_id = 1)) AS ServerAlerts, dbo.Service.name AS ServiceName,
                          (SELECT     COUNT(*) AS Expr1
                            FROM          dbo.Service AS Service_2 INNER JOIN
                                                   dbo.ServerServices AS ServerServices_2 ON Service_2.service_id = ServerServices_2.service_id INNER JOIN
                                                   dbo.Alarm AS Alarm_2 ON ServerServices_2.serverService_id = Alarm_2.serverService_id INNER JOIN
                                                   dbo.Server AS Server_2 ON ServerServices_2.server_id = Server_2.server_id
                            WHERE      (Alarm_2.user_id = 1) AND (Server_2.server_id = dbo.Server.server_id) AND (Service_2.service_id = dbo.Service.service_id)) AS ServiceAlerts,
                          (SELECT     dbo.[User].username
                            FROM          dbo.[User] INNER JOIN
                                                   dbo.Server AS Server_3 ON dbo.[User].user_id = Server_3.userOwner
                            WHERE      (Server_3.server_id = dbo.Server.server_id)) AS Owner,
                          (SELECT     User_2.email
                            FROM          dbo.[User] AS User_2 INNER JOIN
                                                   dbo.Server AS Server_4 ON User_2.user_id = Server_4.userOwner
                            WHERE      (Server_4.server_id = dbo.Server.server_id)) AS Email,
                          (SELECT     User_1.telephone
                            FROM          dbo.[User] AS User_1 INNER JOIN
                                                   dbo.Server AS Server_5 ON User_1.user_id = Server_5.userOwner
                            WHERE      (Server_5.server_id = dbo.Server.server_id)) AS Phone,
                          (SELECT dbo.RealTime.status 
                            FROM dbo.RealTime
                            WHERE (dbo.RealTime.serverService_id = dbo.Alarm.serverService_id)) AS Actually,
                             dbo.Service.resolution AS Solution, dbo.Alarm.instant AS Instant, dbo.Service.service_id AS ServiceId,
                      dbo.Alarm.status AS Status
FROM         dbo.Alarm INNER JOIN
                      dbo.ServerServices ON dbo.Alarm.serverService_id = dbo.ServerServices.serverService_id INNER JOIN
                      dbo.Server ON dbo.ServerServices.server_id = dbo.Server.server_id INNER JOIN
                      dbo.Service ON dbo.ServerServices.service_id = dbo.Service.service_id

WHERE Alarm.alarm_id = @alarmID
GO

CREATE FUNCTION dbo.GetServers(@userID int)
RETURNS TABLE
AS
	RETURN SELECT     dbo.Server.server_id AS ServerId,
                          (SELECT     RealTime_1.status
                            FROM          dbo.RealTime AS RealTime_1 INNER JOIN
                                                   dbo.ServerServices AS ServerServices_1 ON RealTime_1.serverService_id = ServerServices_1.serverService_id
                            WHERE      (ServerServices_1.service_id = 101) AND (ServerServices_1.server_id = dbo.Server.server_id)) AS Status, dbo.Server.name AS Name, 
                      dbo.ServerZone.name AS Zone, dbo.Server.critic AS Critic,
                          (SELECT     COUNT(*) AS Expr1
                            FROM          dbo.ServerServices AS ServerServices_2 INNER JOIN
                                                   dbo.Alarm AS Alarm_1 ON ServerServices_2.serverService_id = Alarm_1.serverService_id
                            WHERE      (ServerServices_2.server_id = dbo.Server.server_id)) AS ServerAlarms,
                          (SELECT     COUNT(*) AS Expr1
                            FROM          dbo.ServerServices AS ServerServices_3 INNER JOIN
                                                   dbo.Alarm AS Alarm_2 ON ServerServices_3.serverService_id = Alarm_2.serverService_id
                            WHERE      (ServerServices_3.server_id = dbo.Server.server_id) AND (Alarm_2.user_id = @userID) AND (Alarm_2.status = 0)) AS CurrentAlarms,
                          (SELECT     TOP (1) Alarm_3.instant AS Ultima
                            FROM          dbo.ServerServices AS ServerServices_4 INNER JOIN
                                                   dbo.Alarm AS Alarm_3 ON ServerServices_4.serverService_id = Alarm_3.serverService_id
                            WHERE      (ServerServices_4.server_id = dbo.Server.server_id) AND (Alarm_3.user_id = @userID)
                            ORDER BY Ultima DESC) AS LastAlarm
FROM         dbo.Server INNER JOIN
                      dbo.ServerZone ON dbo.Server.zone_id = dbo.ServerZone.zone_id INNER JOIN
                      dbo.ServerServices ON dbo.Server.server_id = dbo.ServerServices.server_id INNER JOIN
                      dbo.Permissions ON dbo.ServerServices.serverService_id = dbo.Permissions.serverService_id
WHERE     (dbo.Permissions.user_id = @userID)
GROUP BY dbo.Server.name, dbo.Server.server_id, dbo.ServerZone.name, dbo.Server.critic
GO

CREATE FUNCTION dbo.GetServer(@serverID int, @userID int)
RETURNS TABLE
AS
	RETURN SELECT     dbo.Server.server_id AS ServerId, dbo.Server.dnsname AS ServerDNS, dbo.Server.ip AS ServerIP, dbo.Server.name AS Name, dbo.ServerZone.name AS Zone, 
                      dbo.Server.critic AS Critic, dbo.Server.description AS Description,
                          (SELECT     COUNT(*) AS Expr1
                            FROM          dbo.ServerServices AS ServerServices_2 INNER JOIN
                                                   dbo.Alarm AS Alarm_1 ON ServerServices_2.serverService_id = Alarm_1.serverService_id
                            WHERE      (ServerServices_2.server_id = dbo.Server.server_id)) AS ServerAlarms,
                          (SELECT     COUNT(*) AS Expr1
                            FROM          dbo.ServerServices AS ServerServices_3 INNER JOIN
                                                   dbo.Alarm AS Alarm_2 ON ServerServices_3.serverService_id = Alarm_2.serverService_id
                            WHERE      (ServerServices_3.server_id = dbo.Server.server_id) AND (Alarm_2.user_id = @userID) AND (Alarm_2.status = 0)) AS CurrentAlarms,
                          (SELECT     TOP (1) Alarm_3.instant AS Ultima
                            FROM          dbo.ServerServices AS ServerServices_4 INNER JOIN
                                                   dbo.Alarm AS Alarm_3 ON ServerServices_4.serverService_id = Alarm_3.serverService_id
                            WHERE      (ServerServices_4.server_id = dbo.Server.server_id) AND (Alarm_3.user_id = @userID)
                            ORDER BY Ultima DESC) AS LastAlarm, dbo.[User].name AS OwnerName, dbo.[User].user_id AS OwnerId, dbo.[User].email AS OwnerEmail, 
                      dbo.[User].telephone AS OwnerPhone
FROM         dbo.Server INNER JOIN
                      dbo.ServerZone ON dbo.Server.zone_id = dbo.ServerZone.zone_id INNER JOIN
                      dbo.[User] ON dbo.Server.userOwner = dbo.[User].user_id
WHERE dbo.Server.server_id = @serverID
GO


CREATE FUNCTION dbo.GetRealTimeServer(@serverID int, @userID int)
RETURNS TABLE
AS
	RETURN SELECT     dbo.ServerServices.service_id AS ServiceId, dbo.Service.name AS Name, dbo.RealTime.status AS Status
FROM         dbo.ServerServices INNER JOIN
                      dbo.RealTime ON dbo.ServerServices.serverService_id = dbo.RealTime.serverService_id INNER JOIN
                      dbo.Service ON dbo.ServerServices.service_id = dbo.Service.service_id INNER JOIN
                      dbo.Permissions ON dbo.ServerServices.serverService_id = dbo.Permissions.serverService_id
WHERE     (dbo.ServerServices.server_id = @serverID) AND (dbo.Permissions.user_id = @userID)
GROUP BY dbo.ServerServices.service_id, dbo.Service.name, dbo.RealTime.status
GO


CREATE FUNCTION dbo.GetPermissionsAssigmentByServerForUser(@serverID int, @userId int)
RETURNS TABLE
AS
	RETURN SELECT     dbo.ServerServices.serverService_id  AS Id, dbo.Service.name AS Name
FROM         dbo.Permissions INNER JOIN
                      dbo.ServerServices ON dbo.Permissions.serverService_id = dbo.ServerServices.serverService_id INNER JOIN
                      dbo.Service ON dbo.ServerServices.service_id = dbo.Service.service_id
WHERE     (dbo.ServerServices.server_id = @serverID) AND (dbo.Permissions.user_id = @userId) AND (dbo.ServerServices.status = 1)
GO

CREATE FUNCTION dbo.GetPermissionsUnassigmentByServerForUser(@serverID int, @userId int)
RETURNS TABLE
AS
	RETURN SELECT     dbo.ServerServices.serverService_id  AS Id, dbo.Service.name AS Name
FROM         dbo.Permissions INNER JOIN
                      dbo.ServerServices ON dbo.Permissions.serverService_id = dbo.ServerServices.serverService_id INNER JOIN
                      dbo.Service ON dbo.ServerServices.service_id = dbo.Service.service_id
WHERE     (dbo.ServerServices.server_id = @serverID) AND (dbo.ServerServices.status = 1) AND (dbo.ServerServices.serverService_id NOT IN
                          (SELECT     serverService_id
                            FROM          dbo.Permissions AS Permissions_1
                            WHERE      (user_id = @userId)))
                            GROUP BY dbo.ServerServices.serverService_id , dbo.Service.name
GO

CREATE FUNCTION dbo.GetViewServerList(@userId int)
RETURNS TABLE
AS
	RETURN SELECT     dbo.Server.server_id AS ServerId, dbo.Server.name AS Name, dbo.ServerZone.name AS Zone, dbo.Server.critic AS Critic, dbo.Server.endDate AS Inactive,
                          (SELECT     COUNT(*) AS Expr1
                            FROM          dbo.ServerServices AS ServerServices_2 INNER JOIN
                                                   dbo.Alarm AS Alarm_1 ON ServerServices_2.serverService_id = Alarm_1.serverService_id
                            WHERE      (ServerServices_2.server_id = dbo.Server.server_id)) AS ServerAlarms
FROM         dbo.Server INNER JOIN
                      dbo.ServerZone ON dbo.Server.zone_id = dbo.ServerZone.zone_id INNER JOIN
                      dbo.ServerServices ON dbo.Server.server_id = dbo.ServerServices.server_id INNER JOIN
                      dbo.Permissions ON dbo.ServerServices.serverService_id = dbo.Permissions.serverService_id
WHERE     (dbo.Permissions.user_id = @userID)
GROUP BY dbo.Server.name, dbo.Server.server_id, dbo.ServerZone.name, dbo.Server.critic, dbo.Server.endDate

GO


CREATE FUNCTION dbo.GetHistoryByServerServiceId(@serverId int, @serviceId int)
RETURNS TABLE
AS
	RETURN SELECT     dbo.History.instant, dbo.History.status
FROM         dbo.History INNER JOIN
                      dbo.ServerServices ON dbo.History.serverService_id = dbo.ServerServices.serverService_id
WHERE     (dbo.ServerServices.server_id = @serverId) AND (dbo.ServerServices.service_id = @serviceId)
GO


/****************************************/
/****************************************/
/******                            ******/
/******       Server Monitor       ******/
/****** UOC - TFC - Oriol Foradada ******/
/******         June 2012          ******/
/******                            ******/
/****************************************/
/****************************************/


/*******************************/
/****** INSERT START DATA ******/
/*******************************/



/****** INSERT INTO CONFIGURATION ******/

INSERT INTO [ServerMonitor].[dbo].[Configuration]
           ([conf_id] ,[domainAdminUser], [domainPwdUser],[domain],[serverSMTP],[userSMTP],
			[pwdSMTP],[timeUpdate],[maxTimeCPU],[maxMemoryUsage],[maxHddUsage],[maxTimeOut],[logPath])
     VALUES
           (1, '', '', '', 'smtp.gmail.com', 'ServerMonitorUoc@gmail.com', 'TFC-@2012-Monitor', 30, 5, 90, 90, 10, 'c:\log')
GO


/****** INSERT UserGroups ******/

INSERT INTO [ServerMonitor].[dbo].[UserGroup]
           ([group_id],[name])
     VALUES
           (1, 'Administradors'),
		   (2, 'Usuaris'),
		   (3, 'Convidats')
GO


/****** INSERT ServerZones ******/

INSERT INTO [ServerMonitor].[dbo].[ServerZone]
           ([zone_id],[name])
     VALUES
           (1, 'Corporativa'),
           (2, 'Test'),
           (3, 'Pre-Producci'),
           (4, 'Producci')
GO


/****** INSERT Users ******/

INSERT INTO [ServerMonitor].[dbo].[User]
           ([user_id],[username],[password],[name],[email],[sendEmail],[twitter],
             [sendTwitter],[sms],[sendSMS],[telephone],[group_id],[startDate],[endDate],[comments])
     VALUES
           (0, 'invalidUser', 'invalidPwd','Sistema', '', 0, '',
			0, '', 0, '', 3, '01/01/2001', '01/01/2001', 'Usuari utilitzat per els logins fallits'),
	   	   (1, 'admin', 'admin','Administrador', 'oforadada@uoc.edu', 1, '@oforadada',
			1, '610203040', 1, '931020304', 1, '01/01/2012', '01/01/2001', 'Usuari administrador de la aplicaci'),
           (2, 'user', 'user','Usuari normal', 'oforadada@uoc.edu', 1, '@oforadada',
			1, '650607080', 0, '650607080', 3, '01/01/2001', '01/01/2001', 'Usuari normal de la aplicaci'),
	   	   (3, 'guest', 'guest','Usuari convidat', 'oforadada@uoc.edu', 0, '',
			0, '690001020', 0, '931020304', 1, '01/01/2012', '01/01/2001', 'Usuari convidat de la aplicaci')                        
GO


/****** INSERT Servers ******/

INSERT INTO [ServerMonitor].[dbo].[Server]
           ([server_id],[name],[description],[dnsname],[ip],[zone_id],
            [userOwner],[memory],[cpu],[hdd],[critic], [startDate], [endDate])
     VALUES
           (1, 'AS400', 'Servidor IBM AS400', 'as', '192.168.1.2', 1,
	    1, 0, 0, 0, 1, '01/01/2012', '01/01/2001'),
           (2, 'Niobe', 'Fileserver', 'niobe', '192.168.1.3', 1,
	    1, 4, 2, 4, 1, '01/01/2012', '01/01/2001'),
           (3, 'Porthos', 'Servidor de domini', 'porthos', '192.168.1.4', 1,
	    1, 2, 1, 1, 1, '01/01/2012', '01/01/2001'),
           (4, 'Servidor SQL', 'Servidor de SQL', 'servsql', '192.168.1.7', 1,
	    1, 8, 2, 1, 1, '01/01/2012', '01/01/2001'),
           (5, 'Strogoff', 'Servidor de correu electrnic', 'strogoff.domini.com', '192.168.1.11', 1,
	    1, 8, 2, 1, 1, '01/01/2012', '01/01/2001'),
	       (6, 'Tarificador', 'Tarificador de la centraleta DCC', 'tarificador-vnt', '192.168.1.37', 1,
	    1, 1, 1, 1, 0, '01/01/2012', '01/01/2001'),
           (7, 'Agora', 'Servidor de sharepoint', 'agora', '192.168.1.42', 1,
	    1, 4, 2, 1, 0, '01/01/2012', '01/01/2001'),
           (8, 'Antartida', 'Servidor de Test per els programadors', 'antartida', '192.168.1.90', 1,
	    1, 2, 2, 2, 0, '01/01/2012', '01/01/2001'),
           (9, 'Maslow', 'Servidor A3 de RRHH', 'maslow', '192.168.1.24', 1,
	    1, 2, 1, 1, 0, '01/01/2012', '01/01/2001'),
           (10, 'CTI', 'CTI de la centraleta de DCC', 'cti', '192.168.1.28', 1,
	    1, 1, 1, 1, 1, '01/01/2012', '01/01/2001')

GO


/****** INSERT Service ******/

INSERT INTO [ServerMonitor].[dbo].[Service]
           ([service_id],[name],[description]
           ,[resolution])
     VALUES
           (1,'Firewall', 'Servei que fa de Firewall del sistema',
              'Iniciar el servei i verificar la configuraci'),
           (2,'Antivirus', 'Servei que mostra si l''antivirus esta funcionant',
              'Iniciar el servei i si falla verificar els logs de virus'),
           (3,'Windows Update', 'Servei d''actualitzaci del sistema',
              'Verificar si apunta al servidor local de WSUS'),
           (4,'VMware Tools', 'Servei amb les eines de virtualitzaci',
              'Mirar de reinstalar o upgradar les vmware tools'),
           (5,'SQL Server', 'Servei principal del SQL Server',
              'Iniciar el servei i si falla reiniciar el servidor'),
           (6,'File Server', 'Servei que permet compartir fitxers i recursos',
              'Reiniciar el servidor'),
           (7,'DNS Server', 'Servei de servidor de noms intern (DNS)',
              'Iniciar el servei i si falla reiniciar el servidor'),
           (8,'Spooler', 'Servei de cua d''impresores',
              'Reiniciar el servei. Es perdran les impressions en cua'),
           (9,'IIS', 'Servei de servidor web',
              'Iniciar el servei i si falla reiniciar el servidor'),
           (10,'Exchange', 'Servei principal del servidor de correu',
              'No probar de iniciar el servei, millor reiniciar el servidor'),
           (11,'Char', 'Servei de la aplicaci de tarificaci',
              'Verificar que el SQL tamb funciona, sino reiniciar el servidor'),
           (12,'Sharepoint', 'Servei de Microsoft Sharepoint',
              'Reiniciar el servidor'),
           (13,'Director Actiu', 'Servei de gesti del directori actiu',
              'Reinciar el servidor amb tranquilitat perque est redundat'),
           (14,'iSeries', 'Servei que gestiona la connectivitat amb el AS400',
              'Verificar que no hi ha problemes amb el AS400'),
           (101,'Network', 'Informa de l''estat de la connectivitat de xarxa',
              'Verificar que estigui correctament connectat'),
           (102,'Memory', 'Informa del % de memria utilitzada',
              'Verificar que no hi hagi cap procs en error d''excecuci'),
           (103,'CPU1', 'Informa de l''estat d''activitat de la CPU1',
              'Error crtic'),
           (104,'CPU2', 'Informa de l''estat d''activitat de la CPU2',
              'Error crtic'),
           (105,'CPU3', 'Informa de l''estat d''activitat de la CPU3',
              'Error crtic'),
           (106,'CPU4', 'Informa de l''estat d''activitat de la CPU4',
              'Error crtic'),
           (107,'HDD1', 'Informa del % d''espai ocupat a HDD1',
              'Error crtic d''espai en disc de sistema'),
           (108,'HDD2', 'Informa del % d''espai ocupat a HDD2',
              'Error crtic d''espai en disc'),
           (109,'HDD3', 'Informa del % d''espai ocupat a HDD3',
              'Error crtic d''espai en disc'),
           (110,'HDD4', 'Informa del % d''espai ocupat a HDD3',
              'Error crtic d''espai en disc')
GO


/****** INSERT ServerServives ******/

INSERT INTO [ServerMonitor].[dbo].[ServerServices]
			([serverService_id], [server_id], [service_id], [status])
     VALUES
		   (1,1,1,0),
		   (2,1,2,0),
		   (3,1,3,0),
		   (4,1,4,0),
		   (5,1,5,0),
		   (6,1,6,0),
		   (7,1,7,0),
		   (8,1,8,0),
		   (9,1,9,0),
		   (10,1,10,0),
		   (11,1,11,0),
		   (12,1,12,0),
		   (13,1,13,0),
		   (14,1,14,0),
		   (15,1,101,1),
		   (16,1,102,0),
		   (17,1,103,0),
		   (18,1,104,0),
		   (19,1,105,0),
		   (20,1,106,0),
		   (21,1,107,0),
		   (22,1,108,0),
		   (23,1,109,0),
		   (24,1,110,0),
		   (25,2,1,1),
		   (26,2,2,1),
		   (27,2,3,1),
		   (28,2,4,1),
		   (29,2,5,0),
		   (30,2,6,1),
		   (31,2,7,0),
		   (32,2,8,0),
		   (33,2,9,0),
		   (34,2,10,0),
		   (35,2,11,0),
		   (36,2,12,0),
		   (37,2,13,0),
		   (38,2,14,0),
		   (39,2,101,1),
		   (40,2,102,1),
		   (41,2,103,1),
		   (42,2,104,1),
		   (43,2,105,0),
		   (44,2,106,0),
		   (45,2,107,1),
		   (46,2,108,1),
		   (47,2,109,1),
		   (48,2,110,1),
		   (49,3,1,1),
		   (50,3,2,1),
		   (51,3,3,1),
		   (52,3,4,1),
		   (53,3,5,0),
		   (54,3,6,0),
		   (55,3,7,1),
		   (56,3,8,1),
		   (57,3,9,0),
		   (58,3,10,0),
		   (59,3,11,0),
		   (60,3,12,0),
		   (61,3,13,1),
		   (62,3,14,0),
		   (63,3,101,1),
		   (64,3,102,1),
		   (65,3,103,1),
		   (66,3,104,1),
		   (67,3,105,0),
		   (68,3,106,0),
		   (69,3,107,1),
		   (70,3,108,0),
		   (71,3,109,0),
		   (72,3,110,0),
		   (73,4,1,1),
		   (74,4,2,1),
		   (75,4,3,1),
		   (76,4,4,1),
		   (77,4,5,1),
		   (78,4,6,0),
		   (79,4,7,0),
		   (80,4,8,0),
		   (81,4,9,0),
		   (82,4,10,0),
		   (83,4,11,0),
		   (84,4,12,1),
		   (85,4,13,0),
		   (86,4,14,1),
		   (87,4,101,1),
		   (88,4,102,1),
		   (89,4,103,1),
		   (90,4,104,1),
		   (91,4,105,1),
		   (92,4,106,1),
		   (93,4,107,1),
		   (94,4,108,1),
		   (95,4,109,1),
		   (96,4,110,1),
		   (97,5,1,1),
		   (98,5,2,1),
		   (99,5,3,1),
		   (100,5,4,1),
		   (101,5,5,1),
		   (102,5,6,0),
		   (103,5,7,0),
		   (104,5,8,0),
		   (105,5,9,1),
		   (106,5,10,1),
		   (107,5,11,0),
		   (108,5,12,1),
		   (109,5,13,0),
		   (110,5,14,0),
		   (111,5,101,1),
		   (112,5,102,1),
		   (113,5,103,1),
		   (114,5,104,1),
		   (115,5,105,1),
		   (116,5,106,1),
		   (117,5,107,1),
		   (118,5,108,1),
		   (119,5,109,1),
		   (120,5,110,1),
		   (121,6,1,1),
		   (122,6,2,1),
		   (123,6,3,1),
		   (124,6,4,1),
		   (125,6,5,1),
		   (126,6,6,0),
		   (127,6,7,0),
		   (128,6,8,0),
		   (129,6,9,0),
		   (130,6,10,0),
		   (131,6,11,1),
		   (132,6,12,0),
		   (133,6,13,0),
		   (134,6,14,0),
		   (135,6,101,1),
		   (136,6,102,1),
		   (137,6,103,1),
		   (138,6,104,0),
		   (139,6,105,0),
		   (140,6,106,0),
		   (141,6,107,1),
		   (142,6,108,0),
		   (143,6,109,0),
		   (144,6,110,0),
		   (145,7,1,1),
		   (146,7,2,1),
		   (147,7,3,1),
		   (148,7,4,1),
		   (149,7,5,1),
		   (150,7,6,1),
		   (151,7,7,1),
		   (152,7,8,0),
		   (153,7,9,1),
		   (154,7,10,0),
		   (155,7,11,0),
		   (156,7,12,1),
		   (157,7,13,0),
		   (158,7,14,1),
		   (159,7,101,1),
		   (160,7,102,1),
		   (161,7,103,1),
		   (162,7,104,1),
		   (163,7,105,0),
		   (164,7,106,0),
		   (165,7,107,1),
		   (166,7,108,1),
		   (167,7,109,0),
		   (168,7,110,0),
		   (169,8,1,1),
		   (170,8,2,1),
		   (171,8,3,1),
		   (172,8,4,1),
		   (173,8,5,1),
		   (174,8,6,0),
		   (175,8,7,0),
		   (176,8,8,0),
		   (177,8,9,1),
		   (178,8,10,0),
		   (179,8,11,0),
		   (180,8,12,0),
		   (181,8,13,0),
		   (182,8,14,1),
		   (183,8,101,1),
		   (184,8,102,1),
		   (185,8,103,1),
		   (186,8,104,0),
		   (187,8,105,0),
		   (188,8,106,0),
		   (189,8,107,1),
		   (190,8,108,0),
		   (191,8,109,0),
		   (192,8,110,0),
	       (193,9,1,1),
		   (194,9,2,1),
		   (195,9,3,1),
		   (196,9,4,1),
		   (197,9,5,1),
		   (198,9,6,1),
		   (199,9,7,0),
		   (200,9,8,1),
		   (201,9,9,0),
		   (202,9,10,0),
		   (203,9,11,0),
		   (204,9,12,0),
		   (205,9,13,0),
		   (206,9,14,0),
		   (207,9,101,1),
		   (208,9,102,1),
		   (209,9,103,1),
		   (210,9,104,1),
		   (211,9,105,0),
		   (212,9,106,0),
		   (213,9,107,1),
		   (214,9,108,1),
		   (215,9,109,0),
		   (216,9,110,0),
		   (217,10,1,1),
		   (218,10,2,1),
		   (219,10,3,1),
		   (220,10,4,1),
		   (221,10,5,0),
		   (222,10,6,0),
		   (223,10,7,0),
		   (224,10,8,0),
		   (225,10,9,0),
		   (226,10,10,0),
		   (227,10,11,0),
		   (228,10,12,0),
		   (229,10,13,0),
		   (230,10,14,1),
		   (231,10,101,1),
		   (232,10,102,1),
		   (233,10,103,1),
		   (234,10,104,1),
		   (235,10,105,0),
		   (236,10,106,0),
		   (237,10,107,1),
		   (238,10,108,0),
		   (239,10,109,0),
		   (240,10,110,0)
GO


/****** INSERT Permissions ******/

INSERT INTO [ServerMonitor].[dbo].[Permissions]
           ([serverService_id],[user_id])
     VALUES
           (1,1),
           (2,1),
           (3,1),
           (4,1),
           (5,1),
           (6,1),
           (7,1),
           (8,1),
           (9,1),
           (10,1),
           (11,1),
           (12,1),
           (13,1),
           (14,1),
           (15,1),
           (16,1),
           (17,1),
           (18,1),
           (19,1),
           (20,1),
           (21,1),
           (22,1),
           (23,1),
           (24,1),
           (25,1),
           (26,1),
           (27,1),
           (28,1),
           (29,1),
           (30,1),
           (31,1),
           (32,1),
           (33,1),
           (34,1),
           (35,1),
           (36,1),
           (37,1),
           (38,1),
           (39,1),
           (40,1),
           (41,1),
           (42,1),
           (43,1),
           (44,1),
           (45,1),
           (46,1),
           (47,1),
           (48,1),
           (49,1),
           (50,1),
           (51,1),
           (52,1),
           (53,1),
           (54,1),
           (55,1),
           (56,1),
           (57,1),
           (58,1),
           (59,1),
           (60,1),
           (61,1),
           (62,1),
           (63,1),
           (64,1),
           (65,1),
           (66,1),
           (67,1),
           (68,1),
           (69,1),
           (70,1),
           (71,1),
           (72,1),
           (73,1),
           (74,1),
           (75,1),
           (76,1),
           (77,1),
           (78,1),
           (79,1),
           (80,1),
           (81,1),
           (82,1),
           (83,1),
           (84,1),
           (85,1),
           (86,1),
           (87,1),
           (88,1),
           (89,1),
           (90,1),
           (91,1),
           (92,1),
           (93,1),
           (94,1),
           (95,1),
           (96,1),
           (97,1),
           (98,1),
           (99,1),
           (100,1),
           (101,1),
           (102,1),
           (103,1),
           (104,1),
           (105,1),
           (106,1),
           (107,1),
           (108,1),
           (109,1),
           (110,1),
           (111,1),
           (112,1),
           (113,1),
           (114,1),
           (115,1),
           (116,1),
           (117,1),
           (118,1),
           (119,1),
           (120,1),
           (121,1),
           (122,1),
           (123,1),
           (124,1),
           (125,1),
           (126,1),
           (127,1),
           (128,1),
           (129,1),
           (130,1),
           (131,1),
           (132,1),
           (133,1),
           (134,1),
           (135,1),
           (136,1),
           (137,1),
           (138,1),
           (139,1),
           (140,1),
           (141,1),
           (142,1),
           (143,1),
           (144,1),
           (145,1),
           (146,1),
           (147,1),
           (148,1),
           (149,1),
           (150,1),
           (151,1),
           (152,1),
           (153,1),
           (154,1),
           (155,1),
           (156,1),
           (157,1),
           (158,1),
           (159,1),
           (160,1),
           (161,1),
           (162,1),
           (163,1),
           (164,1),
           (165,1),
           (166,1),
           (167,1),
           (168,1),
           (169,1),
           (170,1),
           (171,1),
           (172,1),
           (173,1),
           (174,1),
           (175,1),
           (176,1),
           (177,1),
           (178,1),
           (179,1),
           (180,1),
           (181,1),
           (182,1),
           (183,1),
           (184,1),
           (185,1),
           (186,1),
           (187,1),
           (188,1),
           (189,1),
           (190,1),
           (191,1),
           (192,1),
           (193,1),
           (194,1),
           (195,1),
           (196,1),
           (197,1),
           (198,1),
           (199,1),
           (200,1),
           (201,1),
           (202,1),
           (203,1),
           (204,1),
           (205,1),
           (206,1),
           (207,1),
           (208,1),
           (209,1),
           (210,1),
           (211,1),
           (212,1),
           (213,1),
           (214,1),
           (215,1),
           (216,1),
           (217,1),
           (218,1),
           (219,1),
           (220,1),
           (221,1),
           (222,1),
           (223,1),
           (224,1),
           (225,1),
           (226,1),
           (227,1),
           (228,1),
           (229,1),
           (230,1),
           (231,1),
           (232,1),
           (233,1),
           (234,1),
           (235,1),
           (236,1),
           (237,1),
           (238,1),
           (239,1),
           (240,1),
           (1,2),
           (2,2),
           (3,2),
           (4,2),
           (5,2),
           (6,2),
           (7,2),
           (8,2),
           (9,2),
           (10,2),
           (11,2),
           (12,2),
           (13,2),
           (14,2),
           (15,2),
           (16,2),
           (17,2),
           (18,2),
           (19,2),
           (20,2),
           (21,2),
           (22,2),
           (23,2),
           (24,2),
           (97,2),
           (98,2),
           (99,2),
           (100,2),
           (101,2),
           (102,2),
           (103,2),
           (104,2),
           (105,2),
           (106,2),
           (107,2),
           (108,2),
           (109,2),
           (110,2),
           (111,2),
           (112,2),
           (113,2),
           (114,2),
           (115,2),
           (116,2),
           (117,2),
           (118,2),
           (119,2),
           (120,2),
           (217,2),
           (218,2),
           (219,2),
           (220,2),
           (221,2),
           (222,2),
           (223,2),
           (224,2),
           (225,2),
           (226,2),
           (227,2),
           (228,2),
           (229,2),
           (230,2),
           (231,2),
           (232,2),
           (233,2),
           (234,2),
           (235,2),
           (236,2),
           (237,2),
           (238,2),
           (239,2),
           (240,2)
GO

INSERT INTO [ServerMonitor].[dbo].[Alarm]
           ([alarm_id],[serverService_id],[user_id],[status])
     VALUES
           (0, 1, 0, 0),
           (1, 15, 1, 0),
           (2, 15, 2, 0),
           (3, 50, 1, 0),
           (4, 51, 1, 0),
           (5, 106, 2, 0),
           (6, 108, 2, 0),
           (7, 149, 1, 0),
           (8, 150, 1, 0),
           (9, 218, 1, 0),
           (10, 218, 2, 0)
GO