﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.ServiceModel.Web;
using System.Text;

using Framework;

namespace ServerMonitorWCF
{

    [ServiceContract]
    public interface IServerInfo
    {

        #region Server

        [OperationContract]
        Server GetServer(int _serverId);

        [OperationContract]
        List<Server> GetAllServers();

        [OperationContract]
        List<Server> GetAllActiveServers();

        [OperationContract]
        ServerZone GetServerZone(int _serverZoneId);

        [OperationContract]
        List<ServerZone> GetAllServerZones();

        [OperationContract]
        bool AddServerZone(string _zone);

        [OperationContract]
        bool UpdateServerZone(ServerZone _serverzone);

        [OperationContract]
        bool DisableServer(string _servername);

        [OperationContract]
        bool EnabledServer(string _servername);

        [OperationContract]
        int AddServer(Server _server);

        [OperationContract]
        int EditServer(Server _server);

        #endregion

        #region Service

        [OperationContract]  
        Service GetService(int _serviceId);

        [OperationContract]   
        List<Service> GetAllServices();

        [OperationContract]
        List<Service> GetServicesByServer(int _serverId);

        [OperationContract]
        bool UpdateService(Service _service);

        #endregion

        #region ServerService

        [OperationContract]
        int GetServerServiceId(int _serverId, int _serviceId);

        [OperationContract]
        int GetServiceOfServerAndServerServiceId(int _serverId, int _serverServiceId);

        [OperationContract]
        int GetSerciceByServerServiceId(int _serverServiceId);

        [OperationContract]
        int GetServerByServerServiceId(int _serverServiceId);

        [OperationContract]
        int MaxServerServiceId();

        [OperationContract]
        bool AddServerService(int _serverId, int _serviceId);

        [OperationContract]
        bool ActiveServerService(int _serverId, int _serviceId);

        [OperationContract]
        bool InactiveServerService(int _serverId, int _serviceId);

        [OperationContract]
        List<ServerService> GetServerServicesByServer(int _serverId);

        #endregion

        #region RealTime_History

        [OperationContract]
        bool DeleteRealTime();

        [OperationContract] 
        bool InsertRealTime(int _serverServiceId, int _status);

        [OperationContract]
        bool UpdatetRealTime(int _serverServiceId, int _status);

        [OperationContract]
        bool InsertHistory(DateTime _instant, int _serverServiceId, int _status);

        [OperationContract]
        bool InsertRealTimeList(List<RealTime> _realTimes);

        [OperationContract]  
        bool InsertHistoryList(List<History> _realTimes);

        [OperationContract]
        List<RealTime> GetRealTimeServer(int _serverId);

        [OperationContract]  
        List<RealTime> GetRealTime();

        [OperationContract]   
        bool CopyRealTimeToHistory();

        #endregion

        #region Configuration

        [OperationContract]
        Configuration GetConfiguration();

        [OperationContract]
        bool UpdateTimeUpdate(int _interval);
        [OperationContract]
        int GetTimeUpdate();

        [OperationContract]
        bool UpdateMaxTimeCPU(int _maxTimeCPU);
        [OperationContract]
        int GetMaxTimeCPU();

        [OperationContract]
        bool UpdateMaxMemoryUsage(int _maxMemoryUsage);
        [OperationContract]   
        int GetMaxMemoryUsage();

        [OperationContract]
        bool UpdateMaxHddUsage(int _maxHddUsage);
        [OperationContract]
        int GetMaxHddUsage();

        [OperationContract]
        bool UpdateLogPath(string _logPath);

        [OperationContract]
        string GetLogPath();

        [OperationContract]
        void writeLog(string _line);
        
        [OperationContract]
        bool UpdateMaxTimeOut(int _maxTimeOut);
        [OperationContract]
        int GetMaxTimeOut();

        [OperationContract]
        string GetServerSMTP();

        [OperationContract]
        string GetUserSMTP();

        [OperationContract]
        string GetPwdSMTP();

        [OperationContract]
        bool SendEmail(string _to, string _subject, string _body);

        [OperationContract]
        bool SendTweet(string _tweetMessage);

        [OperationContract]
        bool SendSMS(string _tlf, string _txt);

        [OperationContract]
        bool NewPassword(string _username);

        [OperationContract]
        bool UpdateConfiguration(Configuration _conf);

        [OperationContract]
        bool existDB();

        #endregion

        #region User

        [OperationContract]
        User GetUserById(int _userId);

        [OperationContract]
        User GetUserByUsername(string _username);

        [OperationContract]
        bool VerifyUser(string _username, string _password);

        [OperationContract]
        bool ChangePassword(string _username, string _password);

        [OperationContract]
        List<User> GetAllUsers();

        [OperationContract]
        List<UserGroup> GetAllUserGroups();

        [OperationContract]
        bool AddUserGroup(string _group);

        [OperationContract]
        bool UpdateUserGroup(UserGroup _group);

        [OperationContract]
        UserGroup GetUserGroup(int _groupId);

        [OperationContract]
        List<User> GetUsersPermissionToServerService(int _serverServiceId);

        [OperationContract]
        bool DisableUser(string _username);

        [OperationContract]
        bool EnabledUser(string _username);

        [OperationContract]
        bool AddUser(User _user);

        [OperationContract]
        bool EditUser(User _user);

        [OperationContract]
        bool UpdatePermissions(int _userId, List<int> _unassigned, List<int> _assigned);

        #endregion

        #region Alarm

        [OperationContract]
        bool NewAlarm(int _serverServiceId, int _userId);

        [OperationContract]
        Alarm GetAlarmById(int _alarmId);

        [OperationContract]       
        bool AlarmLastHourForUser(int _serverServiceId, int _userId);

        [OperationContract]
        List<Alarm> GetAlarmsForUser(int _userId);

        [OperationContract]
        List<Alarm> GetAlarmsUnreadForUser(int _userId);

        [OperationContract]
        bool ReadAlarm(int _alarmId);

        #endregion

        #region AccesLog

        [OperationContract]
        bool InsertAccessLog(int _userId, string _action);

        [OperationContract]
        bool InsertAccessLogSystem(string _action);

        [OperationContract]
        List<AccessLog> GetAccesLogByUserId(int _userId);

        #endregion

        #region Views

        [OperationContract]
        List<vAlerts> GetAlarmsUnreadByUserId(int _userId);

        [OperationContract]
        vAlert GetAlarm(int _alarmId);

        [OperationContract]
        List<vServers> GetServersByUserId(int _userId);

        [OperationContract]
        vServer GetViewServer(int _serverId, int _userId);

        [OperationContract]
        List<vRealTimeServer> GetViewRealTimeServer(int _serverId, int _userId);

        [OperationContract]
        List<vUsers> GetViewUsers();

        [OperationContract]
        List<vPermission> GetServicesUnassigned(int _serverId, int _userId);

        [OperationContract]
        List<vPermission> GetServicesAssigned(int _serverId, int _userId);

        [OperationContract]
        List<vServerList> GetViewServerList(int _userId);

        [OperationContract]
        List<vHistory> GetHistoryByServerServiceId(int _serverId, int _serviceId);

        #endregion

    }
}
