﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.ServiceModel.Web;
using System.Text;

using Framework;

namespace ServerMonitorWCF
{

    public class ServerInfo : IServerInfo
    {
        private IServerDAL _serversInfo = new ServerDALImpl();
        private IServiceDAL _servicesInfo = new ServiceDALImpl();
        private IRealTimeDAL _realTime = new RealTimeDALImpl();
        private IServerServiceDAL _serverService = new ServerServiceDALImpl();
        private IConfigurationDAL _configuration = new ConfigurationDALImpl();
        private IAccessLogDAL _accessLog = new AccessLogDALImpl();
        private IUserDAL _users = new UserDALImpl();
        private IAlarmDAL _alarm = new AlarmDALImpl();
        private IViewDAL _views = new ViewDAL();

        #region Server

        public Server GetServer(int _serverId)
        {
           return _serversInfo.GetServer(_serverId);
        }

        public List<Server> GetAllServers()
        {
            return _serversInfo.GetAllServers();
        }

        public List<Server> GetAllActiveServers()
        {
            return _serversInfo.GetAllActiveServers();
        }

        public ServerZone GetServerZone(int _serverZoneId)
        {
            return _serversInfo.GetServerZone(_serverZoneId);
        }

        public List<ServerZone> GetAllServerZones()
        {
            return _serversInfo.GetAllServerZones();
        }

        public bool AddServerZone(string _zone)
        {
            return _serversInfo.AddServerZone(_zone);
        }

        public bool UpdateServerZone(ServerZone _serverzone)
        {
            return _serversInfo.UpdateServerZone(_serverzone);
        }

        public bool DisableServer(string _servername)
        {
            return _serversInfo.DisableServer(_servername);
        }

        public bool EnabledServer(string _servername)
        {
            return _serversInfo.EnabledServer(_servername);
        }

        public int AddServer(Server _server)
        {
            return _serversInfo.AddServer(_server);
        }

        public int EditServer(Server _server)
        {
            return _serversInfo.EditServer(_server);
        }

        #endregion

        #region Service

        public Service GetService(int _serviceId)
        {
            return _servicesInfo.GetService(_serviceId);
        }

        public List<Service> GetAllServices()
        {
            return _servicesInfo.GetAllServices();
        }

        public List<Service> GetServicesByServer(int _serverId)
        {
            return _servicesInfo.GetServicesByServer(_serverId);
        }

        public bool UpdateService(Service _service)
        {
            return _servicesInfo.UpdateService(_service);
        }

        #endregion

        #region ServerService

        public int GetServerServiceId(int _serverId, int _serviceId)
        {
            return _serverService.GetServerServiceId(_serverId, _serviceId);
        }

        public int GetServiceOfServerAndServerServiceId(int _serverId, int _serverServiceId)
        {
            return _serverService.GetServiceOfServerAndServerServiceId(_serverId, _serverServiceId);
        }

        public int GetSerciceByServerServiceId(int _serverServiceId)
        {
            return _serverService.GetServiceByServerServiceId(_serverServiceId);
        }

        public int GetServerByServerServiceId(int _serverServiceId)
        {
            return _serverService.GetServerByServerServiceId(_serverServiceId);
        }

        public int MaxServerServiceId()
        {
            return _serverService.MaxServerServiceId();
        }

        public bool AddServerService(int _serverId, int _serviceId)
        {
            return _serverService.AddServerService(_serverId, _serviceId);
        }

        public bool ActiveServerService(int _serverId, int _serviceId)
        {
            return _serverService.ActiveServerService(_serverId, _serviceId);
        }

        public bool InactiveServerService(int _serverId, int _serviceId)
        {
            return _serverService.InactiveServerService(_serverId, _serviceId);
        }

        public List<ServerService> GetServerServicesByServer(int _serverId)
        {
            return _serverService.GetServerServicesByServer(_serverId);
        }

        #endregion

        #region RealTime_History

        public bool DeleteRealTime()
        {
            return _realTime.DeleteRealTime();
        }

        public bool InsertRealTime(int _serverServiceId, int _status)
        {
            return _realTime.InsertRealTime(_serverServiceId, _status);
        }

        public bool UpdatetRealTime(int _serverServiceId, int _status)
        {
            return _realTime.UpdatetRealTime(_serverServiceId, _status);
        }

        public bool InsertHistory(DateTime _instant, int _serverServiceId, int _status)
        {
            return _realTime.InsertHistory(_instant, _serverServiceId, _status);
        }
        
        public bool InsertRealTimeList(List<RealTime> _realTimes)
        {
            return _realTime.InsertRealTimeList(_realTimes);
        }

        public bool InsertHistoryList(List<History> _realTimes)
        {
            return _realTime.InsertHistoryList(_realTimes);
        }

        public List<RealTime> GetRealTimeServer(int _serverId)
        {
            return _realTime.GetRealTimeServer(_serverId);
        }

        public List<RealTime> GetRealTime()
        {
            return _realTime.GetRealTime();
        }

        public bool CopyRealTimeToHistory()
        {
            return _realTime.CopyRealTimeToHistory();
        }

        #endregion

        #region Configuration

        public Configuration GetConfiguration()
        {
            return _configuration.GetConfiguration();
        }

        public bool UpdateTimeUpdate(int _interval)
        {
            return _configuration.UpdateTimeUpdate(_interval);
        }

        public int GetTimeUpdate()
        {
            return _configuration.GetTimeUpdate();
        }

        public bool UpdateMaxTimeCPU(int _maxTimeCPU)
        {
            return _configuration.UpdateMaxTimeCPU(_maxTimeCPU);
        }

        public int GetMaxTimeCPU()
        {
            return _configuration.GetMaxTimeCPU();
        }

        public bool UpdateMaxMemoryUsage(int _maxMemoryUsage)
        {
            return _configuration.UpdateMaxMemoryUsage(_maxMemoryUsage);
        }

        public int GetMaxMemoryUsage()
        {
            return _configuration.GetMaxMemoryUsage();
        }

        public bool UpdateMaxHddUsage(int _maxHddUsage)
        {
            return _configuration.UpdateMaxHddUsage(_maxHddUsage);
        }

        public int GetMaxHddUsage()
        {
            return _configuration.GetMaxHddUsage();
        }

        public bool UpdateMaxTimeOut(int _maxTimeOut)
        {
            return _configuration.UpdateMaxTimeOut(_maxTimeOut);
        }

        public int GetMaxTimeOut()
        {
            return _configuration.GetMaxTimeOut();
        }

        public string GetServerSMTP()
        {
            return _configuration.GetServerSMTP();
        }

        public string GetUserSMTP()
        {
            return _configuration.GetUserSMTP();
        }

        public string GetPwdSMTP()
        {
            return _configuration.GetPwdSMTP();
        }

        public bool SendEmail(string _to, string _subject, string _body)
        {
            return _configuration.SendEmail(_to, _subject, _body);
        }

        public bool SendTweet(string _tweetMessage)
        {
            return _configuration.SendTweet(_tweetMessage);
        }

        public bool SendSMS(string _tlf, string _txt)
        {
            return _configuration.SendSMS(_tlf, _txt);
        }

        public bool NewPassword(string _username)
        {
            return _configuration.NewPassword(_username);
        }

        public bool UpdateLogPath(string _logPath)
        {
            return _configuration.UpdateLogPath(_logPath);
        }

        public string GetLogPath()
        {
            return _configuration.GetLogPath();
        }
        
        public void writeLog(string _line)
        {
            _configuration.writeLog(_line);
        }
        
        public bool UpdateConfiguration(Configuration _conf)
        {
            return _configuration.UpdateConfiguration(_conf);
        }

        public bool existDB()
        {
            return _configuration.existDB();
        }

        #endregion

        #region User

        public User GetUserById(int _userId)
        {
            return _users.GetUser(_userId);
        }

        public User GetUserByUsername(string _username)
        {
            return _users.GetUser(_username);
        }

        public bool VerifyUser(string _username, string _password)
        {
            return _users.VerifyUser(_username, _password);
        }

        public bool ChangePassword(string _username, string _password)
        {
            return _users.ChangePassword(_username, _password);
        }

        public List<User> GetAllUsers()
        {
            return _users.GetAllUsers();
        }

        public bool AddUserGroup(string _group)
        {
            return _users.AddUserGroup(_group);
        }

        public bool UpdateUserGroup(UserGroup _group)
        {
            return _users.UpdateUserGroup(_group);
        }

        public List<UserGroup> GetAllUserGroups()
        {
            return _users.GetAllUserGroups();
        }

        public UserGroup GetUserGroup(int _groupId)
        {
            return _users.GetUserGroup(_groupId);
        }

        public List<User> GetUsersPermissionToServerService(int _serverServiceId)
        {
            return _users.GetUsersPermissionToServerService(_serverServiceId);
        }
        
        public bool DisableUser(string _username)
        {
            return _users.DisableUser(_username);
        }

        public bool EnabledUser(string _username)
        {
            return _users.EnabledUser(_username);
        }

        public bool AddUser(User _user)
        {
            return _users.AddUser(_user);
        }

        public bool EditUser(User _user)
        {
            return _users.EditUser(_user);
        }

        public bool UpdatePermissions(int _userId, List<int> _unassigned, List<int> _assigned)
        {
            return _users.UpdatePermissions(_userId, _unassigned, _assigned);
        }

        #endregion

        #region Alarm

        public bool NewAlarm(int _serverServiceId, int _userId)
        {
            return _alarm.NewAlarm(_serverServiceId, _userId);
        }

        public Alarm GetAlarmById(int _alarmId)
        {
            return _alarm.GetAlarmById(_alarmId);
        }

        public bool AlarmLastHourForUser(int _serverServiceId, int _userId)
        {
            return _alarm.AlarmLastHourForUser(_serverServiceId, _userId);
        }

        public List<Alarm> GetAlarmsForUser(int _userId)
        {
            return _alarm.GetAlarmsForUser(_userId);
        }

        public List<Alarm> GetAlarmsUnreadForUser(int _userId)
        {
            return _alarm.GetAlarmsUnreadForUser(_userId);
        }

        public bool ReadAlarm(int _alarmId)
        {
            return _alarm.ReadAlarm(_alarmId);
        }

        #endregion

        #region AccesLog

        public bool InsertAccessLog(int _userId, string _action)
        {
            return _accessLog.InsertAccessLog(_userId, _action);
        }

        public bool InsertAccessLogSystem(string _action)
        {
            return _accessLog.InsertAccessLogSystem(_action);
        }

        public List<AccessLog> GetAccesLogByUserId(int _userId)
        {
            return _accessLog.GetAccesLogByUserId(_userId);
        }

        #endregion

        #region Views

        public List<vAlerts> GetAlarmsUnreadByUserId(int _userId)
        {
            return _views.GetAlarmsUnreadByUserId(_userId);
        }

        public vAlert GetAlarm(int _alarmId)
        {
            return _views.GetAlarm(_alarmId);
        }

        public List<vServers> GetServersByUserId(int _userId)
        {
            return _views.GetServersByUserId(_userId);
        }

        public vServer GetViewServer(int _serverId, int _userId)
        {
            return _views.GetViewServer(_serverId, _userId);
        }

        public List<vRealTimeServer> GetViewRealTimeServer(int _serverId, int _userId)
        {
            return _views.GetViewRealTimeServer(_serverId, _userId);
        }

        public List<vUsers> GetViewUsers()
        {
            return _views.GetViewUsers();
        }

        public List<vPermission> GetServicesUnassigned(int _serverId, int _userId)
        {
            return _views.GetServicesUnassigned(_serverId, _userId);
        }

        public List<vPermission> GetServicesAssigned(int _serverId, int _userId)
        {
            return _views.GetServicesAssigned(_serverId, _userId);
        }

        public List<vServerList> GetViewServerList(int _userId)
        {
            return _views.GetViewServerList(_userId);
        }

        public List<vHistory> GetHistoryByServerServiceId(int _serverId, int _serviceId)
        {
            return _views.GetHistoryByServerServiceId(_serverId, _serviceId);
        }

        #endregion

    }
}
