﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;

using ServerMonitorWP7.ServerInfo;

namespace ServerMonitorWP7.Alerts
{
    public partial class AlertDetail : PhoneApplicationPage
    {
        ServerInfoClient ws_ServerInfo = new ServerInfoClient();

        private static int alarmId;

        public AlertDetail()
        {
            InitializeComponent();
   
        }

        protected override void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {
            //Get the parameters pass by URI (Id of alarm read)
            if (this.NavigationContext.QueryString.ContainsKey("id"))
            {
                string id = NavigationContext.QueryString["id"];
                alarmId = Convert.ToInt32(id);

                getAlert();
            }
        }

        private void getAlert()
        {
            //Event handler and call of this petition on the webService
            ws_ServerInfo.GetAlarmCompleted
                    += new EventHandler<GetAlarmCompletedEventArgs>(getAlertCompleted);

            ws_ServerInfo.GetAlarmAsync(alarmId);

        }
       
        //Event read all information return of the webservice
        private void getAlertCompleted(object sender, GetAlarmCompletedEventArgs e)
        {
            vAlert alert = new vAlert();
            alert = e.Result;

            if (!alert.Equals(null))
            {
                tbServer.Text = alert.Server;
                tbService.Text = alert.Service;
                tbInstant.Text = alert.Instant.ToString();
                tbOwnerName.Text = alert.OwnerName;
                if (!alert.OwnerEmail.Equals(null))
                {
                    bMail.Foreground = new SolidColorBrush(Colors.White);
                    bMail.HorizontalContentAlignment = System.Windows.HorizontalAlignment.Left;
                    bMail.Content = alert.OwnerEmail.Trim();
                }
                if (!alert.OwnerTlf.Equals(null))
                {
                    bPhone.Foreground = new SolidColorBrush(Colors.White);
                    bPhone.HorizontalContentAlignment = System.Windows.HorizontalAlignment.Left;
                    bPhone.Content = alert.OwnerTlf.Trim();
                }

                if (alert.Actually == 0)
                {
                    tbStatus.Text = "Error";
                    tbStatus.Foreground = new SolidColorBrush(Colors.Red);
                }
                else
                {
                    tbStatus.Text = "Correcte";
                    tbStatus.Foreground = new SolidColorBrush(Color.FromArgb(255, 123, 209, 70));
                }

                tbSolution.TextWrapping = TextWrapping.Wrap;
                tbSolution.Text = alert.Solution.Trim();
            }
            else
            {
                MessageBox.Show("Error al carregar la alerta");
                NavigationService.Navigate(new Uri("/Alerts/Alerts.xaml", UriKind.Relative));
            }

        }

        //Button  go to list of Alarms (return)
        private void bAlerts_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/Alerts/Alerts.xaml", UriKind.Relative));
        }

        //Button to go list of Servers
        private void bServers_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/Servers/Servers.xaml", UriKind.Relative));
        }

        //Button to Logoff app
        private void bSortir_Click(object sender, RoutedEventArgs e)
        {
            //Logoff
            MainPage.userId = 0;
            ws_ServerInfo.InsertAccessLogAsync(MainPage.userId, "Ha sortit de la aplicació WP7");
            NavigationService.Navigate(new Uri("/MainPage.xaml", UriKind.Relative));
        }

        private void bReadAlert_Click(object sender, RoutedEventArgs e)
        {
            //Call to webservice to mark read this alert for this user
            ws_ServerInfo.ReadAlarmCompleted
             += new EventHandler<ReadAlarmCompletedEventArgs>(ReadAlarmCompleted);

            ws_ServerInfo.ReadAlarmAsync(alarmId);
            ws_ServerInfo.InsertAccessLogSystemAsync("Lectura de la alerta " + alarmId + " des de WP7");
        }

        private void ReadAlarmCompleted(object sender, ReadAlarmCompletedEventArgs e)
        {

            //Show the message of alarm read and return to Alerts list
            MessageBox.Show("Alarma llegida");
            NavigationService.Navigate(new Uri("/Alerts/Alerts.xaml", UriKind.Relative));
        }

        private void bPhone_Click(object sender, RoutedEventArgs e)
        {
            //Event where use the telephone of owner to call with phone

            var phoneNumberHyperlinkButton = (HyperlinkButton)sender;
            var phoneNumber = (string)phoneNumberHyperlinkButton.Content;

            new Microsoft.Phone.Tasks.PhoneCallTask()
            {
                PhoneNumber = phoneNumber
            }.Show();
        }

        private void bMail_Click(object sender, RoutedEventArgs e)
        {

            //Event call mail configuration in phone for to send a mail
            var eMaillinkButton = (HyperlinkButton)sender;

            var eMail = (string)eMaillinkButton.Content;

            new Microsoft.Phone.Tasks.EmailComposeTask()
            {
                To = eMail
            }.Show();
        }

        //If the user return to this page with BackButton com back to Main Page if this is not loggedIn
        private void PhoneApplicationPage_Loaded(object sender, RoutedEventArgs e)
        {
            if (MainPage.userId.Equals(0))
            {
                NavigationService.Navigate(new Uri("/MainPage.xaml", UriKind.Relative));
            }
        }
    }
}