﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Linq;
using System.ServiceProcess;
using System.Text;

using System.Timers;
using System.IO;
using System.Net;
using System.Net.Mail;

namespace ServerMonitorWS
{
    public partial class Service : ServiceBase
    {
        private static Timer timer = new Timer();
        private static int sizeArray;
        private static DateTime[] serverServicesTmp;
        private static DateTime _emptyTime = new DateTime(0);
        private static string serverSMTP, userSMTP, pwdSMTP;
        private static int timeUpdate, maxTimeCPU, maxMemoryUsage,maxHddUsage, maxTimeOut;
        private static bool _error;

        ServerInfo.ServerInfo wsServerInfo = new ServerInfo.ServerInfo();

        public Service()
        {
            InitializeComponent();

            timer.Interval = 1000;
            timer.Elapsed += new ElapsedEventHandler(timer_Elapsed);

            //create array for the management of service fall time
            serverSMTP = wsServerInfo.GetServerSMTP();
            userSMTP = wsServerInfo.GetUserSMTP();
            pwdSMTP = wsServerInfo.GetPwdSMTP();
            wsServerInfo.GetMaxTimeCPU(out maxTimeCPU, out _error);
            wsServerInfo.GetMaxMemoryUsage(out maxMemoryUsage, out _error);
            wsServerInfo.GetMaxHddUsage(out maxHddUsage, out _error);
            wsServerInfo.GetMaxTimeOut(out maxTimeOut, out _error);
            wsServerInfo.MaxServerServiceId(out sizeArray, out _error);  
            serverServicesTmp = new DateTime[sizeArray];
            _emptyTime = serverServicesTmp[1];

            writeLog("SizeArray: " + sizeArray);
            writeLog(serverSMTP.Trim() + " - " + userSMTP.Trim());
        }

        protected override void OnStart(string[] args)
        {
            timer.Start();
            writeLog("El servei de windows s'acaba d'iniciar");
        }

        protected override void OnStop()
        {
            timer.Stop();
            writeLog("El servei de windows s'acaba d'aturar");
        }

        private void timer_Elapsed(object sender, ElapsedEventArgs e)
        {
                          
            //In all ticks update time interval
            int timeTmp = timeUpdate;
            wsServerInfo.GetTimeUpdate(out timeUpdate, out _error);    
            
            if (timeUpdate != timeTmp)
                writeLog("timeupdate: " + timeUpdate.ToString());
            
            timer.Interval = timeUpdate * 1000;

            //Copy RealTime to History
            wsServerInfo.CopyRealTimeToHistory(out _error, out _error);

            //update arrayTmp?
            wsServerInfo.MaxServerServiceId(out sizeArray, out _error);
            if (sizeArray > serverServicesTmp.Length)
                serverServicesTmp = (DateTime[])RedimArray(serverServicesTmp, sizeArray);

            //Analyze RealTime   
            AnalyzeRealTime();

            //update variables
            wsServerInfo.GetMaxTimeCPU(out maxTimeCPU, out _error);
            wsServerInfo.GetMaxMemoryUsage(out maxMemoryUsage, out _error);
            wsServerInfo.GetMaxHddUsage(out maxHddUsage, out _error);
            wsServerInfo.GetMaxTimeOut(out maxTimeOut, out _error);

        }

        private void AnalyzeRealTime()
        {

            //get RealTime
            ServerInfo.RealTime[] realTime = wsServerInfo.GetRealTime();

            //Verify all stats

            foreach (ServerInfo.RealTime rt in realTime)
            {
                int serviceId;

                wsServerInfo.GetSerciceByServerServiceId(rt.ServerServiceId, _error, out  serviceId, out _error);
                switch (serviceId)
                {
                        //Service of network
                    case 101:

                        if (rt.Status == 0)
                        {
                            writeLog("True - Service: 101 - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status); 
                            VerifyTimeState(rt.ServerServiceId, maxTimeOut);
                        }
                        else
                        {
                            serverServicesTmp[rt.ServerServiceId] = _emptyTime;
                            //writeLog("False - Service: 101 - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status); 
                        }
                        break;

                        //Service of memory
                    case 102:

                        if ((rt.Status > maxMemoryUsage) && (maxMemoryUsage != 0))
                        {
                            writeLog("True - Service: 102 - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status + " - MaxMemory: " + maxMemoryUsage); 
                            VerifyTimeState(rt.ServerServiceId, 0);
                        }
                        else
                        {
                            serverServicesTmp[rt.ServerServiceId] = _emptyTime;
                            //writeLog("False - Service: 102 - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status + " - MaxMemory: " + maxMemoryUsage); 
                        }
                        break;

                        //Service of CPU
                    case 103:
                    case 104:
                    case 105:
                    case 106:

                        if (rt.Status >  95)
                        {
                            writeLog("True - Service: 103-6 - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status + " - MaxTime: " + maxTimeCPU); 
                            VerifyTimeState(rt.ServerServiceId, maxTimeCPU);
                        }
                        else
                        {
                            serverServicesTmp[rt.ServerServiceId] = _emptyTime;
                            //writeLog("False - Service: 103-6 - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status + " - MaxTime: " + maxTimeCPU); 
                        }
                        break;
                       
                        //Service of HDD
                    case 107:
                    case 108:
                    case 109:
                    case 110:

                        if ((rt.Status > maxHddUsage) && (maxHddUsage != 0))
                        {
                            writeLog("True - Service: 107-10 - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status + " - MaxHdd: " + maxHddUsage); 
                            VerifyTimeState(rt.ServerServiceId, 0);
                        }
                        else
                        {
                            serverServicesTmp[rt.ServerServiceId] = _emptyTime;
                           // writeLog("False - Service: 107-10 - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status + " - MaxHdd: " + maxHddUsage); 
                        }
                        break;

                        //Standard services
                    default:
                                                  
                        if (rt.Status == 0)
                        {
                            writeLog("True - Service Standart - ServerServiceId: " + rt.ServerServiceId + " Status: " + rt.Status); 
                            VerifyTimeState(rt.ServerServiceId, 0);
                        }
                        else
                        {
                            serverServicesTmp[rt.ServerServiceId] = _emptyTime;
                        }
                        break;
                        
                }
            }
        }

        private void VerifyTimeState(int _serverServiceId, int _seconds)
        {
            if (_seconds > 0)
            {
                //Service monitor wait time stop

                if (serverServicesTmp[_serverServiceId].Equals(_emptyTime))
                {
                    serverServicesTmp[_serverServiceId] = DateTime.Now;
                }
                else
                {
                    //veryfy how long time is in this state
                    int diference = DateTime.Now.Subtract(serverServicesTmp[_serverServiceId]).Seconds;

                    //if is in this state more time than configured generate alarm
                    if (diference >= _seconds)
                    {
                        //write alarm in db for all users with permissions in this serverService and send alarm
                        CreateAlarm(_serverServiceId);
                    }
                }
            }
            else
            {
                //create alarm
                CreateAlarm(_serverServiceId);
                serverServicesTmp[_serverServiceId] = DateTime.Now;
            }

        }

        private void CreateAlarm(int _serverServiceId)
        {

            ServerInfo.User[] _usersServerService = wsServerInfo.GetUsersPermissionToServerService(_serverServiceId, _error);

            foreach (ServerInfo.User user in _usersServerService)
            {
                //verify if has been sent the same alarm in the last hour
                bool alarmsInLastHour;
                wsServerInfo.AlarmLastHourForUser(_serverServiceId, _error, user.UserId, _error, out alarmsInLastHour, out _error);
                writeLog("Verify alarms in last hour for user: " + user.UserName);
                if (!alarmsInLastHour)
                {
                    //add alarm in DB
                    wsServerInfo.NewAlarm(_serverServiceId, _error, user.UserId, _error, out _error, out _error);

                    //send alarm
                    writeLog("AddAlarm: " + _serverServiceId + " - " + user.UserName);

                    int serverId = 1;
                    int serviceId = 1;
                    wsServerInfo.GetServerByServerServiceId(_serverServiceId, _error, out  serverId, out _error);
                    wsServerInfo.GetSerciceByServerServiceId(_serverServiceId, _error, out  serviceId, out _error);
                    ServerInfo.Server server = wsServerInfo.GetServer(serverId, _error);
                    ServerInfo.Service service = wsServerInfo.GetService(serviceId, _error);
                    ServerInfo.User owner = wsServerInfo.GetUserById(server.UserOwner, _error);

                    if (user.SendEmail)
                    {
                        string subject = "Error al servidor " + server.Name.Trim();
                        string body = "<html><body>";

                        body += "S'ha produit un error al servei <b>" + service.Name.Trim() + "</b> del servidor <b>";

                        body += server.Name.Trim() + "</b> a les " + DateTime.Now + "<br><br>";
                        body += "      El responsable d'aquest servidor és <b><u>" + owner.Name.Trim() + "</u></b><br>" +
                                "      Si vols possar-te en contacte amb ell ho pots fer per email a ";

                        body += "<a href=mailto:" + owner.Email.Trim() + ">" + owner.Email.Trim() + "</a><br>";

                        if (owner.Telephone.Trim().Length > 1)

                            body += "      o bé per telèfon al " + owner.Telephone.Trim() + "<br>";


                        body += "<br>ServerMonitor</body></html>";
                        wsServerInfo.SendEmail(user.Email.Trim(), subject, body, out _error, out _error);

                        writeLog("Email enviat a:" + user.Email.Trim());
                    }

                    if (user.SendTwitter)
                    {
                        wsServerInfo.SendTweet("D " + user.Twitter.Trim() + " S'ha produit un error al servei " + service.Name.Trim() + " del servidor " + server.Name.Trim(), out _error, out  _error);
                    }

                    if (user.SendSMS)
                    {
                        wsServerInfo.SendSMS(user.SMS, "S'ha produit un error al servei " + service.Name.Trim() + " del servidor " + server.Name.Trim(), out _error, out _error);
                    }
                }
            }
        }

        private static Array RedimArray(Array orgArray, int size)
        {
            Type t = orgArray.GetType().GetElementType();
            Array nArray = Array.CreateInstance(t, size);
            Array.Copy(orgArray, 0, nArray, 0, Math.Min(orgArray.Length, size));

            return nArray;
        }
        
        private void writeLog(string _line)
        {
            //New method - write by webService
            wsServerInfo.writeLog(_line);
        }
    
    }
}
