﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace ServerMonitorWeb.Config.Alerts
{
    public partial class ConfigAlerts : System.Web.UI.Page
    {

        ServerInfo.ServerInfoClient ws = new ServerInfo.ServerInfoClient();

        protected void Page_Load(object sender, EventArgs e)
        {
            
            if (Session["UserLogged"] == null || Session["UserLogged"] == "false")
            {
                Response.Redirect("~/Errors/Error.aspx");
            }
            
            try
            {

                Init();

                List<ServerInfo.Service> services = ws.GetAllServices();
                GridViewServices.DataSource = services;
                GridViewServices.DataBind();
            }
            catch
            {
                Response.Redirect("~/Errors/Error.aspx");
            }
        }

        protected void GridViewServices_RowDataBound(object sender, GridViewRowEventArgs e)
        {

            if (e.Row.RowType == DataControlRowType.DataRow)
            {
                ServerInfo.Service service = e.Row.DataItem as ServerInfo.Service;
                
                // Id

                Label _id = new Label();

                _id.Text = service.Id.ToString();
                e.Row.Cells[0].Controls.Add(_id);


                // Service

                Label _service = new Label();

                _service.Text = service.Name;
                e.Row.Cells[1].Controls.Add(_service);

                // Description

                TextBox _description = new TextBox();

                _description.Text = service.Description;
                _description.Width = 180;
                _description.Height = 60;
                _description.Wrap = true;
                _description.TextMode = TextBoxMode.MultiLine;
                _description.BorderStyle = BorderStyle.None;
                _description.ReadOnly = true;
                e.Row.Cells[2].Controls.Add(_description);

                // Ressolution

                TextBox _ressolution = new TextBox();

                _ressolution.Text = service.Ressolution;
                _ressolution.Width = 180;
                _ressolution.Height = 60;
                _ressolution.Wrap = true;
                _ressolution.TextMode = TextBoxMode.MultiLine;
                _ressolution.BorderStyle = BorderStyle.None;
                _ressolution.ReadOnly = true;
                e.Row.Cells[3].Controls.Add(_ressolution);

                //Modify

                Button _modify = new Button();

                _modify.Text = "Modificar";
                _modify.CommandArgument = service.Id.ToString();
                _modify.Command += new CommandEventHandler(this._modify_Click);
                e.Row.Cells[4].Controls.Add(_modify);
            }
        }

        private void Init()
        {
            //CPU
            for (int num = 0; num < 16; num++)
            {
                ListItem ic = new ListItem();

                ic.Text = num.ToString();
                ic.Value = num.ToString();
                ddlCPU.Items.Add(ic);
            }

            //Memory
            for (int num = 5; num < 100; num += 5)
            {
                ListItem im = new ListItem();

                im.Text = num.ToString();
                im.Value = num.ToString();
                ddlMemory.Items.Add(im);
            }

            //HDD
            for (int num = 5; num < 100; num += 5)
            {
                ListItem ih = new ListItem();

                ih.Text = num.ToString();
                ih.Value = num.ToString();
                ddlHDD.Items.Add(ih);
            }

            //Network
            for (int num = 0; num < 11; num++)
            {
                ListItem ix = new ListItem();

                ix.Text = num.ToString();
                ix.Value = num.ToString();
                ddlNetwork.Items.Add(ix);
            }
        }

        protected void _modify_Click(object sender, CommandEventArgs e)
        {
            Response.Redirect("./EditService.aspx?id=" + e.CommandArgument.ToString());
        }

        protected void bSave_Click(object sender, EventArgs e)
        {
            try
            {
                ws.UpdateMaxTimeCPU(Convert.ToInt32(ddlCPU.SelectedValue));
                ws.UpdateMaxMemoryUsage(Convert.ToInt32(ddlMemory.SelectedValue));
                ws.UpdateMaxHddUsage(Convert.ToInt32(ddlHDD.SelectedValue));
                ws.UpdateMaxTimeOut(Convert.ToInt32(ddlNetwork.SelectedValue));

                lbResult.Text = "S'ha guardat correctament la informació";
                lbResult.ForeColor = System.Drawing.Color.Green;
                ws.InsertAccessLog((int)Session["UserId"], "Modificació dels umbrals de les alertes"); 
            }
            catch
            {
                lbResult.Text = "S'ha produit un error al salvar la informació";
                lbResult.ForeColor = System.Drawing.Color.Red;
            }
        }

        protected void bExit_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Default.aspx");
        }

        protected void GridViewServices_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            this.GridViewServices.PageIndex = e.NewPageIndex;
            this.GridViewServices.DataBind();
        }
    }
}