﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;

namespace ServerMonitorWeb.Config.App
{
    public partial class ConfigApp : System.Web.UI.Page
    {

        ServerInfo.ServerInfoClient ws = new ServerInfo.ServerInfoClient();

        protected void Page_Load(object sender, EventArgs e)
        {

            if (Session["UserLogged"] == null || Session["UserLogged"] == "false")
            {
                Response.Redirect("~/Errors/Error.aspx");
            }

            try
            {
                if (!Page.IsPostBack)
                {
                    Session["updateDdlZones"] = "true";
                    Session["updateDdlGroups"] = "true";
                }
                Init();
            }
            catch
            {
                Response.Redirect("~/Errors/Error.aspx");
            }

        }

        private void Init()
        {

            if (!Page.IsPostBack)
            {
                ServerInfo.Configuration conf = ws.GetConfiguration();

                tbNameAdmin.Text = conf.DomainAdminUser;
                tbPasswordAdmin.Text = conf.DomainPwdUser;
                tbDomainAdmin.Text = conf.DomainPwdUser;

                tbServer.Text = conf.ServerSMTP;
                tbUserSMTP.Text = conf.UserSMTP;
                tbPwdSMTP.Text = conf.PwdSMTP;
                
                // TimeUpdate
                ddlTimeUpdate.Items.Clear();
                for (int num = 10; num < 70; num += 10)
                {
                    ListItem itu = new ListItem();

                    itu.Text = num.ToString() + " seg. ";
                    itu.Value = num.ToString();
                    ddlTimeUpdate.Items.Add(itu);
                }
                ddlTimeUpdate.Items.FindByValue(conf.TimeUpdate.ToString()).Selected = true;
            }

            if (Session["updateDdlZones"].Equals("true"))
            {
                List<ServerInfo.ServerZone> zones = ws.GetAllServerZones();
                ddlZones.Items.Clear();
                foreach (ServerInfo.ServerZone zone in zones)
                {
                    ListItem itZone = new ListItem(zone.Name.Trim(), zone.Id.ToString());
                    ddlZones.Items.Add(itZone);
                }
                Session["updateDdlZones"] = "false";
            }

            if (Session["updateDdlGroups"].Equals("true"))
            {
                List<ServerInfo.UserGroup> groups = ws.GetAllUserGroups();
                ddlGroups.Items.Clear();
                foreach (ServerInfo.UserGroup group in groups)
                {
                    ListItem itGroup = new ListItem(group.Name.Trim(), group.GroupId.ToString());
                    ddlGroups.Items.Add(itGroup);
                }
                Session["updateDdlGroups"] = "false";
            }
        }

        protected void bNewZone_Click(object sender, EventArgs e)
        {
            try
            {
                if (tbNewZone.Text.Length > 2)
                {
                    ws.AddServerZone(tbNewZone.Text);
                    ws.InsertAccessLog((int)Session["UserId"], "S'ha creat una nova zona " + tbNewZone.Text); 
                    Session["updateDdlZones"] = "true";
                    Response.Redirect(Request.RawUrl);
                }
            }
            catch
            {
                lbResult.Text = "Error al crear la zona";
                lbResult.ForeColor = System.Drawing.Color.Red;
            }
        }

        protected void bEditZone_Click(object sender, EventArgs e)
        {
            try
            {
                if (tbEditZone.Text.Length > 2)
                {
                    List<ServerInfo.ServerZone> zones = ws.GetAllServerZones();
                    ServerInfo.ServerZone zone = new ServerInfo.ServerZone();

                    foreach (ServerInfo.ServerZone tmp in zones)
                    {
                        if (tmp.Name.Equals(ddlZones.SelectedItem.Text))
                            zone = tmp;
                    }

                    zone.Name = tbEditZone.Text;

                    ws.UpdateServerZone(zone);

                    Session["updateDdlZones"] = "true";

                    lbResult.Text = "S'ha modificat correctament la zona";
                    lbResult.ForeColor = System.Drawing.Color.Green;
                    ws.InsertAccessLog((int)Session["UserId"], "Ha modificat la zona " + zone.Name); 
                    Response.Redirect(Request.RawUrl);
                }
            }
            catch
            {
                lbResult.Text = "Error al modificar la zona";
                lbResult.ForeColor = System.Drawing.Color.Red;
            }
        }

        protected void ddlZones_SelectedIndexChanged(object sender, EventArgs e)
        {
            tbEditZone.Text = ddlZones.SelectedItem.Text;
        }

        protected void bNewGroup_Click(object sender, EventArgs e)
        {
            try
            {
                if (tbNewGroup.Text.Length > 2)
                {
                    ws.AddUserGroup(tbNewGroup.Text);

                    Session["updateDdlGroups"] = "true";
                    ws.InsertAccessLog((int)Session["UserId"], "S'ha creat un nou grup d'usuaris anomenat " + tbNewGroup.Text); 
                    Response.Redirect(Request.RawUrl);
                }
            }
            catch
            {
                lbResult.Text = "Error al crear el grup";
                lbResult.ForeColor = System.Drawing.Color.Red;
            }
        }

        protected void ddlGroups_SelectedIndexChanged(object sender, EventArgs e)
        {
            tbEditGroup.Text = ddlGroups.SelectedItem.Text;
        }

        protected void bEditGroup_Click(object sender, EventArgs e)
        {
            try
            {
                if (tbEditGroup.Text.Length > 2)
                {
                    List<ServerInfo.UserGroup> groups = ws.GetAllUserGroups();
                    ServerInfo.UserGroup group = new ServerInfo.UserGroup();

                    foreach (ServerInfo.UserGroup tmp in groups)
                    {
                        if (tmp.Name.Equals(ddlGroups.SelectedItem.Text))
                            group = tmp;
                    }

                    group.Name = tbEditGroup.Text;

                    ws.UpdateUserGroup(group);

                    Session["updateDdlGroups"] = "true";

                    lbResult.Text = "S'ha modificat correctament la zona";
                    lbResult.ForeColor = System.Drawing.Color.Green;
                    ws.InsertAccessLog((int)Session["UserId"], "S'ha modificat el nom del grup " + 
                                       group.GroupId.ToString() + " amb " + group.Name); 
                    Response.Redirect(Request.RawUrl);
                }
            }
            catch
            {
                lbResult.Text = "Error al modificar la zona";
                lbResult.ForeColor = System.Drawing.Color.Red;
            }
        }

        protected void bSendEmail_Click(object sender, EventArgs e)
        {
            try
            {
                UpdateConf();
                ws.SendEmail(tbEmailTest.Text.Trim(), "Test configuració ServerMonitor", "Test d'email enviat " + DateTime.Now);
                lbResult.Text = "S'ha enviat un mail de test a " + tbEmailTest.Text.Trim();
                lbResult.ForeColor = System.Drawing.Color.Green;
            }
            catch
            {
                lbResult.Text = "Error al enviar el mail de test";
                lbResult.ForeColor = System.Drawing.Color.Red;
            }
        }

        protected void bSave_Click(object sender, EventArgs e)
        {
            try
            {

                if (UpdateConf())
                {
                    lbResult.Text = "S'ha modificat correctament la informació a la base de dades";
                    lbResult.ForeColor = System.Drawing.Color.Green;
                    ws.InsertAccessLog((int)Session["UserId"], "Ha modificat la configuració de la aplicació"); 
                }
                else
                {
                    lbResult.Text = "Error al actualitzar la informació a la base de dades";
                    lbResult.ForeColor = System.Drawing.Color.Red;
                }
            }
            catch
            {
                lbResult.Text = "Error al actualitzar la informació a la base de dades";
                lbResult.ForeColor = System.Drawing.Color.Red;
            }
        }

        private bool UpdateConf()
        {

            ServerInfo.Configuration conf = new ServerInfo.Configuration();


            conf.DomainAdminUser = tbNameAdmin.Text;
            conf.DomainPwdUser = tbPasswordAdmin.Text;
            conf.Domain = tbDomainAdmin.Text;

            conf.ServerSMTP = tbServer.Text;
            conf.UserSMTP = tbUserSMTP.Text;
            conf.PwdSMTP = tbPwdSMTP.Text;

            return ws.UpdateConfiguration(conf);
        
        }

        protected void bExit_Click(object sender, EventArgs e)
        {
            Response.Redirect("~/Default.aspx");
        }

    }
}