﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace ServerMonitorWeb.Config.Servers
{
    public partial class ConfigServers : System.Web.UI.Page
    {
        
        ServerInfo.ServerInfoClient ws = new ServerInfo.ServerInfoClient();
        
        protected void Page_Load(object sender, EventArgs e)
        {

            if (Session["UserLogged"] == null || Session["UserLogged"] == "false")
            {
                Response.Redirect("~/Errors/Error.aspx");
            }

            try
            {
                List<ServerInfo.vServerList> servers = ws.GetViewServerList(Convert.ToInt32(Session["UserId"].ToString()));

                GridViewServers.DataSource = servers;
                GridViewServers.DataBind();
              
            }
            catch
            {
                Response.Redirect("~/Errors/Error.aspx");
            }
        }

        protected void GridViewServers_RowDataBound(object sender, GridViewRowEventArgs e)
        {

            if (e.Row.RowType == DataControlRowType.DataRow)
            {

                ServerInfo.vServerList server = e.Row.DataItem as ServerInfo.vServerList;

               // Id

               Label _id = new Label();

                _id.Text = server.Id.ToString();
                e.Row.Cells[0].Controls.Add(_id);


                // Server

                Label _server = new Label();

                _server.Text = server.Name;
                e.Row.Cells[1].Controls.Add(_server);

                // Zone

                Label _zone = new Label();

                _zone.Text = server.Zone;
                e.Row.Cells[2].Controls.Add(_zone);

                // Critic


                if (server.Critic)
                {
                    ImageButton _critic = new ImageButton();
                    Button _dCritic = new Button();
                    _critic.AlternateText = "Crític";
                    _critic.ImageUrl = "~/img/warning.png";
                    _critic.Width = 30;
                    _critic.Height = 30;

                    e.Row.Cells[3].Controls.Add(_critic);
                }
                else
                {
                    Label critic = new Label();
                    critic.Text = "";
                    e.Row.Cells[3].Controls.Add(critic);
                }

                // Active
                ImageButton _active = new ImageButton();
                Button _disable = new Button();

                if (server.EndDate.Equals(new DateTime(2001, 01, 01)))
                {
                    _active.AlternateText = "Actiu";
                    _active.ImageUrl = "~/img/server-ok.png";

                    _disable.Text = "Deshabilitar servidor";
                    _disable.CommandArgument = server.Name;
                    _disable.Command += new CommandEventHandler(this._disable_Click);

                }
                else
                {
                    _active.AlternateText = "Baixa";
                    _active.ImageUrl = "~/img/server-ko.png";

                    _disable.Text = "Habilitar servidor";
                    _disable.CommandArgument = server.Name;
                    _disable.Command += new CommandEventHandler(this._enabled_Click);

                }

                _active.ImageAlign = ImageAlign.Middle;
                _active.Width = 30;
                _active.Height = 30;

                e.Row.Cells[4].Controls.Add(_active);


                // Alerts

                Label _alerts = new Label();

                _alerts.Text = server.TotalAlarms.ToString();
                e.Row.Cells[5].Controls.Add(_alerts);


                // Modify

                Button _modify = new Button();

                _modify.Text = "Modificar";
                _modify.CommandArgument = server.Id.ToString();
                _modify.Command += new CommandEventHandler(this._modify_Click);
                e.Row.Cells[6].Controls.Add(_modify);

                // Disable User

                e.Row.Cells[7].Controls.Add(_disable);
            }

        }

        protected void _modify_Click(object sender, CommandEventArgs e)
        {
            Response.Redirect("./EditServer.aspx?id=" + e.CommandArgument.ToString());
        }

        protected void _disable_Click(object sender, CommandEventArgs e)
        {
            if (ws.DisableServer(e.CommandArgument.ToString()))
            {
                lbInfo.Text = "El servidor " + e.CommandArgument + " s'ha deshabilitat";
                lbInfo.ForeColor = System.Drawing.Color.Green;
                ws.InsertAccessLog((int)Session["UserId"], "Ha deshabilitat el servidor " + e.CommandArgument); 
            }
            else
            {
                lbInfo.Text = "Error al deshabilitar el servidor " + e.CommandArgument.ToString();
                lbInfo.ForeColor = System.Drawing.Color.Red;
            }
            Response.Redirect(Request.RawUrl);
        }

        protected void _enabled_Click(object sender, CommandEventArgs e)
        {
            if (ws.EnabledServer(e.CommandArgument.ToString()))
            {
                lbInfo.Text = "El servidor" + e.CommandArgument + " s'ha habilitat correctament";
                lbInfo.ForeColor = System.Drawing.Color.Green;
                ws.InsertAccessLog((int)Session["UserId"], "Ha habilitat el servidor " + e.CommandArgument); 
            }
            else
            {
                lbInfo.Text = "El servidor " + e.CommandArgument.ToString();
                lbInfo.ForeColor = System.Drawing.Color.Red;
            }
            Response.Redirect(Request.RawUrl);
        }

        protected void bNewServer_Click(object sender, EventArgs e)
        {
            Response.Redirect("./NewServer.aspx");
        }

        protected void GViewServers_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            this.GridViewServers.PageIndex = e.NewPageIndex;
            this.GridViewServers.DataBind();
        }
    }
}