﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace ServerMonitorWeb.Config.Servers
{
    public partial class EditServer : System.Web.UI.Page
    {
        ServerInfo.ServerInfoClient ws = new ServerInfo.ServerInfoClient();

        protected void Page_Load(object sender, EventArgs e)
        {
            if (Session["UserLogged"] == null || Session["UserLogged"] == "false")
            {
                Response.Redirect("~/Errors/Error.aspx");
            }

            try
            {
                if (!Page.IsPostBack)
                {
                    subTitle.Text += ws.GetServer(Convert.ToInt32(Request.Params["Id"])).Name.Trim();
                    Initialice();
                    GetServer();
                }
            }
            catch
            {
                Response.Redirect("~/Errors/Error.aspx");
            }

        }

        private void Initialice()
        {

            // Generate all services

            List<ServerInfo.Service> services = ws.GetAllServices();

            List<TableCell> tcs = new List<TableCell>();

            foreach (ServerInfo.Service service in services)
            {
                if (service.Id < 101)
                {

                    ListItem lt = new ListItem();

                    lt.Value = service.Id.ToString();
                    lt.Text = service.Name;
                    CheckBoxListServices.Items.Add(lt);
                }
            }

            CheckBoxListServices.RepeatColumns = 3;

            // Genereate dropdownlist

            //CPU
            for (int num = 0; num < 5; num++)
            {
                ListItem ic = new ListItem();

                ic.Text = num.ToString();
                ic.Value = num.ToString();
                ddlCPU.Items.Add(ic);
            }

            //CPU & HDD
            for (int num = 0; num < 5; num++)
            {
                ListItem ih = new ListItem();

                ih.Text = num.ToString();
                ih.Value = num.ToString();
                ddlHDD.Items.Add(ih);
            }

            // Memory
            for (int num = 0; num < 9; num++)
            {
                ListItem it = new ListItem();

                it.Text = num.ToString();
                it.Value = num.ToString();
                ddlMemory.Items.Add(it);
            }


            // DDL Critic

            ddlCritic.Items.Add("Normal");
            ddlCritic.Items.Add("Crític");


            // DDL Zonez
            List<ServerInfo.ServerZone> zones = ws.GetAllServerZones();

            foreach (ServerInfo.ServerZone zone in zones)
            {
                ListItem lzone = new ListItem();

                lzone.Value = zone.Id.ToString();
                lzone.Text = zone.Name;

                ddlZone.Items.Add(lzone);
            }

            // Owner
            List<ServerInfo.vUsers> users = ws.GetViewUsers();

            foreach (ServerInfo.vUsers user in users)
            {
                ListItem luser = new ListItem();

                luser.Value = user.UserId.ToString();
                luser.Text = user.Name;

                ddlOwner.Items.Add(luser);
            }

        }

        private void GetServer()
        {
            ServerInfo.Server server = ws.GetServer(Convert.ToInt32(Request.Params["Id"]));

            tbName.Text = server.Name.Trim();
            tbDNS.Text = server.DnsName.Trim();
            tbIP.Text = server.Ip.Trim();
            tbDescription.Text = server.Description.Trim();
            ddlZone.SelectedValue = server.ZoneId.ToString();
            
            if (server.Critic)
                ddlCritic.SelectedValue = "Crític";
            else
                ddlCritic.SelectedValue = "Normal";

            ddlOwner.SelectedValue = server.UserOwner.ToString();
            ddlCPU.SelectedValue = server.CPU.ToString();
            ddlHDD.SelectedValue = server.HDD.ToString();
            ddlMemory.SelectedValue = server.Memory.ToString();

            List<ServerInfo.ServerService> ss = ws.GetServerServicesByServer(Convert.ToInt32(Request.Params["Id"]));

            foreach (ServerInfo.ServerService _ss in ss)
            {
                if (_ss.ServiceId <= 101)
                {
                    if (_ss.ServiceId == 101)
                        s_101.Checked = true;
                    else
                        CheckBoxListServices.Items.FindByValue(_ss.ServiceId.ToString()).Selected = true;
                }
            }

        }

        protected void bExit_Click(object sender, EventArgs e)
        {
            Response.Redirect("./ConfigServers.aspx");
        }

        protected void bSave_Click(object sender, EventArgs e)
        {
            try
            {
                int serverId = UpdateServer();

                if (serverId > 0)
                {

                    foreach (ListItem srv in CheckBoxListServices.Items)
                    {
                        if (srv.Selected)
                        {
                            ws.ActiveServerService(serverId, Convert.ToInt32(srv.Value));
                        }
                        else
                        {
                            ws.InactiveServerService(serverId, Convert.ToInt32(srv.Value));
                        }
                    }

                    // Network
                    if (s_101.Checked)
                        ws.ActiveServerService(serverId, 101);
                    else
                        ws.InactiveServerService(serverId, 101);

                    // Memory
                    if (Convert.ToInt32(ddlMemory.SelectedValue) > 0)
                        ws.ActiveServerService(serverId, 102);
                    else
                        ws.InactiveServerService(serverId, 102);

                    // CPU
                    int cpu = Convert.ToInt32(ddlCPU.SelectedValue);
                    
                    ws.InactiveServerService(serverId, 103);
                    ws.InactiveServerService(serverId, 104);
                    ws.InactiveServerService(serverId, 105);
                    ws.InactiveServerService(serverId, 106);
                    
                    for (int i = 103; i < cpu + 103; i++)
                        ws.AddServerService(serverId, i);

                    // HDD
                    int hdd = Convert.ToInt32(ddlHDD.SelectedValue);
                    
                    ws.InactiveServerService(serverId, 107);
                    ws.InactiveServerService(serverId, 108);
                    ws.InactiveServerService(serverId, 109);
                    ws.InactiveServerService(serverId, 110);

                    for (int i = 107; i < hdd + 107; i++)
                        ws.AddServerService(serverId, i);
                    
                    lbResult.ForeColor = System.Drawing.Color.Green;
                    lbResult.Text = "S'ha modificat correctament";
                    ws.InsertAccessLog((int)Session["UserId"], "Modificació del servidor " + serverId + " - " + ws.GetServer(serverId).Name); 
                }
            }
            catch
            {
                lbResult.ForeColor = System.Drawing.Color.Red;
                lbResult.Text = "S'ha produit un error al modificar el servidor a la base de dades";
            }
        }

        private int UpdateServer()
        {
            ServerInfo.Server server = new ServerInfo.Server();

            server.Name = tbName.Text.Trim();
            server.DnsName = tbDNS.Text.Trim();
            server.Ip = tbIP.Text.Trim();
            server.Description = tbDescription.Text.Trim();
            server.UserOwner = Convert.ToInt32(ddlOwner.SelectedValue);
            if (ddlCritic.SelectedValue.Equals("Normal"))
            {
                server.Critic = false;
            }
            else
            {
                server.Critic = true;
            }
            server.ZoneId = Convert.ToInt32(ddlZone.SelectedValue);
            server.CPU = Convert.ToInt32(ddlCPU.SelectedValue);
            server.HDD = Convert.ToInt32(ddlHDD.SelectedValue);
            server.Memory = Convert.ToInt32(ddlMemory.SelectedValue);

            return ws.EditServer(server);
        }

    }
}