﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace ServerMonitorWeb.Config.Servers
{
    public partial class NewServer : System.Web.UI.Page
    {

        ServerInfo.ServerInfoClient ws = new ServerInfo.ServerInfoClient();

        protected void Page_Load(object sender, EventArgs e)
        {

            if (Session["UserLogged"] == null || Session["UserLogged"] == "false")
            {
                Response.Redirect("~/Errors/Error.aspx");
            }

            try
            {
                if (!Page.IsPostBack)
                {
                    Initialice();
                }               
            }
            catch
            {
                Response.Redirect("~/Errors/Error.aspx");
            }
        }

        private void Initialice()
        {

            // Generate all services

            List<ServerInfo.Service> services = ws.GetAllServices();

            List<TableCell> tcs = new List<TableCell>();

            foreach (ServerInfo.Service service in services)
            {
                if (service.Id < 101)
                {

                    ListItem lt = new ListItem();

                    lt.Value = service.Id.ToString();
                    lt.Text = service.Name;
                    CheckBoxListServices.Items.Add(lt);
                }
            }

            CheckBoxListServices.RepeatColumns = 3;

            // Genereate dropdownlist

            //CPU
            for (int num = 0; num < 5; num++)
            {
                ListItem ic = new ListItem();

                ic.Text = num.ToString();
                ic.Value = num.ToString();
                ddlCPU.Items.Add(ic);
            }

            //CPU & HDD
            for (int num = 0; num < 5; num++)
            {
                ListItem ih = new ListItem();

                ih.Text = num.ToString();
                ih.Value = num.ToString();
                ddlHDD.Items.Add(ih);
            }

            // Memory
            for (int num = 0; num < 9; num++)
            {
                ListItem it = new ListItem();

                it.Text = num.ToString();
                it.Value = num.ToString();
                ddlMemory.Items.Add(it);
            }


            // DDL Critic

            ddlCritic.Items.Add("Normal");
            ddlCritic.Items.Add("Crític");


            // DDL Zonez
            List<ServerInfo.ServerZone> zones = ws.GetAllServerZones();

            foreach (ServerInfo.ServerZone zone in zones)
            {
                ListItem lzone = new ListItem();

                lzone.Value = zone.Id.ToString();
                lzone.Text = zone.Name;

                ddlZone.Items.Add(lzone);
            }

            // Owner
            List<ServerInfo.vUsers> users = ws.GetViewUsers();

            foreach (ServerInfo.vUsers user in users)
            {
                ListItem luser = new ListItem();

                luser.Value = user.UserId.ToString();
                luser.Text = user.Name;

                ddlOwner.Items.Add(luser);
            }

        }

        protected void bExit_Click(object sender, EventArgs e)
        {
            Response.Redirect("./ConfigServers.aspx");
        }

        protected void bSave_Click(object sender, EventArgs e)
        {
            try
            {
                int serverId =  AddServer();
                List<int> _unassigned = new List<int>();
                List<int> _assigned = new List<int>();

                if (serverId > 0)
                {

                    foreach (ListItem srv in CheckBoxListServices.Items)
                    {
                        if (srv.Selected)
                        
                            ws.ActiveServerService(serverId, Convert.ToInt32(srv.Value));

                    }

                    // Network
                    if (s_101.Checked)
               
                        ws.ActiveServerService(serverId, 101);
                    
                    // Memory
                    if (Convert.ToInt32(ddlMemory.SelectedValue) > 0)
                    
                        ws.ActiveServerService(serverId, 102);

                    // CPU
                    int cpu = Convert.ToInt32(ddlCPU.SelectedValue);

                    for (int i = 103; i < cpu + 103; i++)
                    
                        ws.ActiveServerService(serverId, i);


                    // HDD
                    int hdd = Convert.ToInt32(ddlHDD.SelectedValue);

                    for (int i = 107; i < hdd + 107; i++)
                    
                        ws.ActiveServerService(serverId, i);


                    lbResult.ForeColor = System.Drawing.Color.Green;
                    lbResult.Text = "S'ha introduit correctament";

                       
                    //add permissions to the owner

                    List<ServerInfo.ServerService> servicesActive =  ws.GetServerServicesByServer(serverId);
                    foreach(ServerInfo.ServerService sa in servicesActive)
                    {
                        _assigned.Add(sa.ServerServiceId);
                    }

                    ws.UpdatePermissions(Convert.ToInt32(ddlOwner.SelectedValue), _unassigned, _assigned);
 
                    ws.InsertAccessLog((int)Session["UserId"], "Ha creat el servidor " + serverId + " - " + ws.GetServer(serverId).Name); 
                }
            }
            catch
            {
                lbResult.ForeColor = System.Drawing.Color.Red;
                lbResult.Text = "S'ha produit un error al inserir el servidor a la base de dades";
            }
        }

        private int AddServer()
        {
            ServerInfo.Server server = new ServerInfo.Server();

            server.Name = tbName.Text.Trim();
            server.DnsName = tbDNS.Text.Trim();
            server.Ip = tbIP.Text.Trim();
            server.Description = tbDescription.Text.Trim();
            server.UserOwner = Convert.ToInt32(ddlOwner.SelectedValue);
            if (ddlCritic.SelectedValue.Equals("Normal"))
            {
                server.Critic = false;
            }
            else
            {
                server.Critic = true;
            }
            server.ZoneId = Convert.ToInt32(ddlZone.SelectedValue);
            server.CPU = Convert.ToInt32(ddlCPU.SelectedValue);
            server.HDD = Convert.ToInt32(ddlHDD.SelectedValue);
            server.Memory = Convert.ToInt32(ddlMemory.SelectedValue);

            return ws.AddServer(server);
        }

    }
}